[![Git](https://git-scm.com/images/logo@2x.png)](https://git-scm.com/) --everything-is-local
![](https://git-scm.com/images/dark-mode.svg)
  * [About](https://git-scm.com/about)
    * [Trademark](https://git-scm.com/about/trademark)
  * [Learn](https://git-scm.com/learn)
    * [Book](https://git-scm.com/book)
    * [Cheat Sheet](https://git-scm.com/cheat-sheet)
    * [Videos](https://git-scm.com/videos)
    * [External Links](https://git-scm.com/doc/ext)
  * [Tools](https://git-scm.com/tools)
    * [Command Line](https://git-scm.com/tools/command-line)
    * [GUIs](https://git-scm.com/tools/guis)
    * [Hosting](https://git-scm.com/tools/hosting)
  * [Reference](https://git-scm.com/docs)
  * [Install](https://git-scm.com/install/linux)
  * [Community](https://git-scm.com/community)


[ Deutsch ▾](https://git-scm.com/docs/git/de)
Localized versions of **git** manual
  1. [English ](https://git-scm.com/docs/git)
  2. [Deutsch ](https://git-scm.com/docs/git/de)
  3. [Español ](https://git-scm.com/docs/git/es)
  4. [Français ](https://git-scm.com/docs/git/fr)
  5. [Português (Brasil) ](https://git-scm.com/docs/git/pt_BR)
  6. [Svenska ](https://git-scm.com/docs/git/sv)
  7. [українська мова ](https://git-scm.com/docs/git/uk)
  8. [简体中文 ](https://git-scm.com/docs/git/zh_HANS-CN)

Want to read in your language or fix typos?
[You can help translate this page](https://github.com/jnavila/git-manpages-l10n).
[Topics ▾](https://git-scm.com/docs/git/de)
### Setup and Config
  * [ git ](https://git-scm.com/docs/git/de)
  * [ config ](https://git-scm.com/docs/git-config/de)
  * [ help ](https://git-scm.com/docs/git-help)
  * [ bugreport ](https://git-scm.com/docs/git-bugreport)
  * [ Credential helpers ](https://git-scm.com/doc/credential-helpers)


### Getting and Creating Projects
  * [ init ](https://git-scm.com/docs/git-init/de)
  * [ clone ](https://git-scm.com/docs/git-clone/de)


### Basic Snapshotting
  * [ add ](https://git-scm.com/docs/git-add/de)
  * [ status ](https://git-scm.com/docs/git-status)
  * [ diff ](https://git-scm.com/docs/git-diff/de)
  * [ commit ](https://git-scm.com/docs/git-commit)
  * [ notes ](https://git-scm.com/docs/git-notes)
  * [ restore ](https://git-scm.com/docs/git-restore/de)
  * [ reset ](https://git-scm.com/docs/git-reset)
  * [ rm ](https://git-scm.com/docs/git-rm)
  * [ mv ](https://git-scm.com/docs/git-mv/de)


### Branching and Merging
  * [ branch ](https://git-scm.com/docs/git-branch)
  * [ checkout ](https://git-scm.com/docs/git-checkout)
  * [ switch ](https://git-scm.com/docs/git-switch)
  * [ merge ](https://git-scm.com/docs/git-merge)
  * [ mergetool ](https://git-scm.com/docs/git-mergetool)
  * [ log ](https://git-scm.com/docs/git-log)
  * [ stash ](https://git-scm.com/docs/git-stash)
  * [ tag ](https://git-scm.com/docs/git-tag)
  * [ worktree ](https://git-scm.com/docs/git-worktree)


### Sharing and Updating Projects
  * [ fetch ](https://git-scm.com/docs/git-fetch)
  * [ pull ](https://git-scm.com/docs/git-pull)
  * [ push ](https://git-scm.com/docs/git-push)
  * [ remote ](https://git-scm.com/docs/git-remote)
  * [ submodule ](https://git-scm.com/docs/git-submodule)


### Inspection and Comparison
  * [ show ](https://git-scm.com/docs/git-show)
  * [ log ](https://git-scm.com/docs/git-log)
  * [ diff ](https://git-scm.com/docs/git-diff/de)
  * [ difftool ](https://git-scm.com/docs/git-difftool)
  * [ range-diff ](https://git-scm.com/docs/git-range-diff)
  * [ shortlog ](https://git-scm.com/docs/git-shortlog)
  * [ describe ](https://git-scm.com/docs/git-describe)


### Patching
  * [ apply ](https://git-scm.com/docs/git-apply)
  * [ cherry-pick ](https://git-scm.com/docs/git-cherry-pick)
  * [ diff ](https://git-scm.com/docs/git-diff/de)
  * [ rebase ](https://git-scm.com/docs/git-rebase)
  * [ revert ](https://git-scm.com/docs/git-revert)


### Debugging
  * [ bisect ](https://git-scm.com/docs/git-bisect)
  * [ blame ](https://git-scm.com/docs/git-blame)
  * [ grep ](https://git-scm.com/docs/git-grep)


### Email
  * [ am ](https://git-scm.com/docs/git-am)
  * [ apply ](https://git-scm.com/docs/git-apply)
  * [ imap-send ](https://git-scm.com/docs/git-imap-send)
  * [ format-patch ](https://git-scm.com/docs/git-format-patch)
  * [ send-email ](https://git-scm.com/docs/git-send-email)
  * [ request-pull ](https://git-scm.com/docs/git-request-pull)


### External Systems
  * [ svn ](https://git-scm.com/docs/git-svn)
  * [ fast-import ](https://git-scm.com/docs/git-fast-import)


### Server Admin
  * [ daemon ](https://git-scm.com/docs/git-daemon)
  * [ update-server-info ](https://git-scm.com/docs/git-update-server-info)


### Guides
  * [ gitattributes ](https://git-scm.com/docs/gitattributes)
  * [ Command-line interface conventions ](https://git-scm.com/docs/gitcli)
  * [ Everyday Git ](https://git-scm.com/docs/giteveryday)
  * [ Frequently Asked Questions (FAQ) ](https://git-scm.com/docs/gitfaq)
  * [ Glossary ](https://git-scm.com/docs/gitglossary/de)
  * [ Hooks ](https://git-scm.com/docs/githooks)
  * [ gitignore ](https://git-scm.com/docs/gitignore)
  * [ gitmodules ](https://git-scm.com/docs/gitmodules)
  * [ Revisions ](https://git-scm.com/docs/gitrevisions)
  * [ Submodules ](https://git-scm.com/docs/gitsubmodules)
  * [ Tutorial ](https://git-scm.com/docs/gittutorial)
  * [ Workflows ](https://git-scm.com/docs/gitworkflows)
  * [ All guides... ](https://git-scm.com/docs/git#_guides)


### Administration
  * [ clean ](https://git-scm.com/docs/git-clean)
  * [ gc ](https://git-scm.com/docs/git-gc)
  * [ fsck ](https://git-scm.com/docs/git-fsck)
  * [ reflog ](https://git-scm.com/docs/git-reflog)
  * [ filter-branch ](https://git-scm.com/docs/git-filter-branch)
  * [ instaweb ](https://git-scm.com/docs/git-instaweb)
  * [ archive ](https://git-scm.com/docs/git-archive)
  * [ bundle ](https://git-scm.com/docs/git-bundle)


### Plumbing Commands
  * [ cat-file ](https://git-scm.com/docs/git-cat-file)
  * [ check-ignore ](https://git-scm.com/docs/git-check-ignore)
  * [ checkout-index ](https://git-scm.com/docs/git-checkout-index)
  * [ commit-tree ](https://git-scm.com/docs/git-commit-tree)
  * [ count-objects ](https://git-scm.com/docs/git-count-objects)
  * [ diff-index ](https://git-scm.com/docs/git-diff-index)
  * [ for-each-ref ](https://git-scm.com/docs/git-for-each-ref)
  * [ hash-object ](https://git-scm.com/docs/git-hash-object)
  * [ ls-files ](https://git-scm.com/docs/git-ls-files)
  * [ ls-tree ](https://git-scm.com/docs/git-ls-tree)
  * [ merge-base ](https://git-scm.com/docs/git-merge-base)
  * [ read-tree ](https://git-scm.com/docs/git-read-tree)
  * [ rev-list ](https://git-scm.com/docs/git-rev-list/de)
  * [ rev-parse ](https://git-scm.com/docs/git-rev-parse)
  * [ show-ref ](https://git-scm.com/docs/git-show-ref)
  * [ symbolic-ref ](https://git-scm.com/docs/git-symbolic-ref)
  * [ update-index ](https://git-scm.com/docs/git-update-index)
  * [ update-ref ](https://git-scm.com/docs/git-update-ref)
  * [ verify-pack ](https://git-scm.com/docs/git-verify-pack)
  * [ write-tree ](https://git-scm.com/docs/git-write-tree/de)


[ Latest version ▾ ](https://git-scm.com/docs/git/de) git last updated in 2.53.0
Changes in the **git** manual
  1. [2.53.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2026-02-02_ ](https://git-scm.com/docs/git/2.53.0)
  2. [2.52.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2025-11-17_ ](https://git-scm.com/docs/git/2.52.0)
  3. 2.51.2 no changes
  4. [2.51.1 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2025-10-15_ ](https://git-scm.com/docs/git/2.51.1)
  5. 2.50.1 → 2.51.0 no changes
  6. [2.50.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2025-06-16_ ](https://git-scm.com/docs/git/2.50.0)
  7. 2.49.1 no changes
  8. [2.49.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2025-03-14_ ](https://git-scm.com/docs/git/2.49.0)
  9. 2.48.1 → 2.48.2 no changes
  10. [2.48.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2025-01-10_ ](https://git-scm.com/docs/git/2.48.0)
  11. 2.47.1 → 2.47.3 no changes
  12. [2.47.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-10-06_ ](https://git-scm.com/docs/git/2.47.0)
  13. 2.46.1 → 2.46.4 no changes
  14. [2.46.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-07-29_ ](https://git-scm.com/docs/git/2.46.0)
  15. 2.45.2 → 2.45.4 no changes
  16. [2.45.1 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-04-29_ ](https://git-scm.com/docs/git/2.45.1)
  17. [2.45.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-04-29_ ](https://git-scm.com/docs/git/2.45.0)
  18. 2.44.2 → 2.44.4 no changes
  19. [2.44.1 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-04-19_ ](https://git-scm.com/docs/git/2.44.1)
  20. [2.44.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-02-23_ ](https://git-scm.com/docs/git/2.44.0)
  21. 2.43.5 → 2.43.7 no changes
  22. [2.43.4 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-04-19_ ](https://git-scm.com/docs/git/2.43.4)
  23. 2.43.2 → 2.43.3 no changes
  24. [2.43.1 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-02-09_ ](https://git-scm.com/docs/git/2.43.1)
  25. [2.43.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2023-11-20_ ](https://git-scm.com/docs/git/2.43.0)
  26. 2.42.3 → 2.42.4 no changes
  27. [2.42.2 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-04-19_ ](https://git-scm.com/docs/git/2.42.2)
  28. [2.42.1 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2023-11-02_ ](https://git-scm.com/docs/git/2.42.1)
  29. [2.42.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2023-08-21_ ](https://git-scm.com/docs/git/2.42.0)
  30. 2.41.2 → 2.41.3 no changes
  31. [2.41.1 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-04-19_ ](https://git-scm.com/docs/git/2.41.1)
  32. [2.41.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2023-06-01_ ](https://git-scm.com/docs/git/2.41.0)
  33. 2.40.3 → 2.40.4 no changes
  34. [2.40.2 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-04-19_ ](https://git-scm.com/docs/git/2.40.2)
  35. 2.40.1 no changes
  36. 2.40.0 no changes
  37. 2.39.5 no changes
  38. [2.39.4 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-04-19_ ](https://git-scm.com/docs/git/2.39.4)
  39. 2.39.1 → 2.39.3 no changes
  40. [2.39.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2022-12-12_ ](https://git-scm.com/docs/git/2.39.0)
  41. 2.38.3 → 2.38.5 no changes
  42. [2.38.2 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2022-12-11_ ](https://git-scm.com/docs/git/2.38.2)
  43. 2.38.1 no changes
  44. [2.38.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2022-10-02_ ](https://git-scm.com/docs/git/2.38.0)
  45. 2.37.3 → 2.37.7 no changes
  46. [2.37.2 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2022-08-11_ ](https://git-scm.com/docs/git/2.37.2)
  47. 2.37.1 no changes
  48. [2.37.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2022-06-27_ ](https://git-scm.com/docs/git/2.37.0)
  49. 2.36.1 → 2.36.6 no changes
  50. [2.36.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2022-04-18_ ](https://git-scm.com/docs/git/2.36.0)
  51. 2.35.1 → 2.35.8 no changes
  52. [2.35.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2022-01-24_ ](https://git-scm.com/docs/git/2.35.0)
  53. 2.34.1 → 2.34.8 no changes
  54. [2.34.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2021-11-15_ ](https://git-scm.com/docs/git/2.34.0)
  55. 2.33.3 → 2.33.8 no changes
  56. [2.33.2 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2022-03-23_ ](https://git-scm.com/docs/git/2.33.2)
  57. [2.33.1 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2021-10-12_ ](https://git-scm.com/docs/git/2.33.1)
  58. 2.32.1 → 2.33.0 no changes
  59. [2.32.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2021-06-06_ ](https://git-scm.com/docs/git/2.32.0)
  60. 2.31.1 → 2.31.8 no changes
  61. [2.31.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2021-03-15_ ](https://git-scm.com/docs/git/2.31.0)
  62. 2.30.1 → 2.30.9 no changes
  63. [2.30.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2020-12-27_ ](https://git-scm.com/docs/git/2.30.0)
  64. 2.29.1 → 2.29.3 no changes
  65. [2.29.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2020-10-19_ ](https://git-scm.com/docs/git/2.29.0)
  66. 2.28.1 no changes
  67. [2.28.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2020-07-27_ ](https://git-scm.com/docs/git/2.28.0)
  68. 2.27.1 no changes
  69. [2.27.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2020-06-01_ ](https://git-scm.com/docs/git/2.27.0)
  70. 2.26.1 → 2.26.3 no changes
  71. [2.26.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2020-03-22_ ](https://git-scm.com/docs/git/2.26.0)
  72. 2.25.2 → 2.25.5 no changes
  73. [2.25.1 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2020-02-17_ ](https://git-scm.com/docs/git/2.25.1)
  74. [2.25.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2020-01-13_ ](https://git-scm.com/docs/git/2.25.0)
  75. 2.23.1 → 2.24.4 no changes
  76. [2.23.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2019-08-16_ ](https://git-scm.com/docs/git/2.23.0)
  77. 2.22.2 → 2.22.5 no changes
  78. [2.22.1 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2019-08-11_ ](https://git-scm.com/docs/git/2.22.1)
  79. [2.22.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2019-06-07_ ](https://git-scm.com/docs/git/2.22.0)
  80. 2.20.1 → 2.21.4 no changes
  81. [2.20.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2018-12-09_ ](https://git-scm.com/docs/git/2.20.0)
  82. 2.19.3 → 2.19.6 no changes
  83. [2.19.2 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2018-11-21_ ](https://git-scm.com/docs/git/2.19.2)
  84. 2.19.1 no changes
  85. [2.19.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2018-09-10_ ](https://git-scm.com/docs/git/2.19.0)
  86. 2.18.1 → 2.18.5 no changes
  87. [2.18.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2018-06-21_ ](https://git-scm.com/docs/git/2.18.0)
  88. 2.17.1 → 2.17.6 no changes
  89. [2.17.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2018-04-02_ ](https://git-scm.com/docs/git/2.17.0)
  90. [2.16.6 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2019-12-06_ ](https://git-scm.com/docs/git/2.16.6)
  91. [2.15.4 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2019-12-06_ ](https://git-scm.com/docs/git/2.15.4)
  92. [2.14.6 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2019-12-06_ ](https://git-scm.com/docs/git/2.14.6)
  93. 2.13.7 no changes
  94. [2.12.5 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-09-22_ ](https://git-scm.com/docs/git/2.12.5)
  95. [2.11.4 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-09-22_ ](https://git-scm.com/docs/git/2.11.4)
  96. [2.10.5 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-09-22_ ](https://git-scm.com/docs/git/2.10.5)
  97. [2.9.5 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-07-30_ ](https://git-scm.com/docs/git/2.9.5)
  98. [2.8.6 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-07-30_ ](https://git-scm.com/docs/git/2.8.6)
  99. [2.7.6 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-07-30_ ](https://git-scm.com/docs/git/2.7.6)
  100. [2.6.7 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-05-05_ ](https://git-scm.com/docs/git/2.6.7)
  101. [2.5.6 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-05-05_ ](https://git-scm.com/docs/git/2.5.6)
  102. [2.4.12 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-05-05_ ](https://git-scm.com/docs/git/2.4.12)
  103. [2.3.10 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2015-09-28_ ](https://git-scm.com/docs/git/2.3.10)
  104. [2.2.3 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2015-09-04_ ](https://git-scm.com/docs/git/2.2.3)
  105. [2.1.4 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2014-12-17_ ](https://git-scm.com/docs/git/2.1.4)
  106. [2.0.5 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2014-12-17_ ](https://git-scm.com/docs/git/2.0.5)


Check your version of git by running
`git --version`
##  [](https://git-scm.com/docs/git/de#_name)NAME
git - der stupide Content-Tracker
##  [](https://git-scm.com/docs/git/de#_%C3%BCbersicht)ÜBERSICHT
```
_git_ [-v | --version] [-h | --help] [-C <path>] [-c <name>=<value>]
    [--exec-path[=<path>]] [--html-path] [--man-path] [--info-path]
    [-p|--paginate|-P|--no-pager] [--no-replace-objects] [--bare]
    [--git-dir=<path>] [--work-tree=<path>] [--namespace=<name>]
    [--super-prefix=<path>] [--config-env=<name>=<envvar>]
    <command> [<args>]
```

##  [](https://git-scm.com/docs/git/de#_beschreibung)BESCHREIBUNG
Git ist ein schnelles skalierbares verteiltes Versionskontrollsystem mit einem ungewöhnlich umfangreichen Befehlssatz, der sowohl hochrangige Operationen als auch vollen Zugriff auf interne Abläufe bietet.
Siehe [gittutorial[7]](https://git-scm.com/docs/gittutorial/de) für den Einstieg und anschließend [giteveryday[7]](https://git-scm.com/docs/giteveryday/de) für einen nützlichen Mindestbefehlssatz. Das [Git-Nutzerhandbuch](https://git-scm.com/docs/user-manual/de) enthält eine tiefergehende Einführung.
Wenn Sie die grundlegenden Konzepte verstanden haben, können Sie auf dieser Seite lernen, welche Befehle Git anbietet. Mit "git help <Befehl>" können Sie mehr über einzelne Git-Befehle erfahren. Die Handbuchseite [gitcli[7]](https://git-scm.com/docs/gitcli/de) bietet Ihnen einen Überblick über die Befehlszeilen-Syntax.
Eine HTML-Version der aktuellen Git-Dokumentation mit Formatierung und Verknüpfungen ist unter <https://git.github.io/htmldocs/git.html> oder <https://git-scm.com/docs> verfügbar.
##  [](https://git-scm.com/docs/git/de#_optionen)OPTIONEN

[](https://git-scm.com/docs/git/de#git--v)-v


[](https://git-scm.com/docs/git/de#git---version)--version

Gibt die Version der Git-Suite, aus der das _git_ -Programm stammt, aus.
This option is internally converted to `git version ...` and accepts the same options as the [git-version[1]](https://git-scm.com/docs/git-version/de) command. If `--help` is also given, it takes precedence over `--version`.

[](https://git-scm.com/docs/git/de#git--h)-h


[](https://git-scm.com/docs/git/de#git---help)--help

Gibt eine Übersicht und eine Liste der gebräuchlichsten Befehle aus. Wenn die Option `--all` oder `-a` angegeben wurde, werden alle verfügbaren Befehle ausgegeben. Falls der Name eines Git-Befehls angegeben wurde, wird die Handbuchseite für diesen Befehl geöffnet.
Zur Steuerung wie die Handbuchseite dargestellt wird sind andere Optionen verfügbar. Weitere Informationen finden Sie unter [git-help[1]](https://git-scm.com/docs/git-help/de), weil `git --help ...` intern in `git help ...` konvertiert wird.

[](https://git-scm.com/docs/git/de#git--CltPfadgt)-C <Pfad>

Git ausführen, als ob Git in _< Pfad>_ statt dem aktuellen Arbeitsverzeichnis gestartet wurde. Falls die Option `-C` mehrfach angegeben wurde, wird jeder nicht-absolute `-C <Pfad>` als relativ zum vorherigen `-C <Pfad>` interpretiert. Wenn _< Pfad>_ existiert, aber leer ist (also `-C ""`), wird das aktuelle Arbeitsverzeichnis nicht verändert.
Diese Option beeinflusst andere Optionen, die Pfade erwarten, wie `--git-dir`und `--work-tree`, da ihre Pfade relativ zum Arbeitsverzeichnis, das über `-C` angegeben wurde, interpretiert werden. Die folgenden Aufrufe sind z.B. identisch:
```
git --git-dir=a.git --work-tree=b -C c status
git --git-dir=c/a.git --work-tree=c/b status
```


[](https://git-scm.com/docs/git/de#git--cltNamegtltWertgt)-c <Name>=<Wert>

Übergibt einen Konfigurationsparameter an den Befehl. Der übergebene Wert Überschreibt Werte aus Konfigurationsdateien. Der <Name> wird im gleichen Format erwartet, das von _git config_ ausgegeben wird. (Unterschlüssel durch Punkte getrennt).
Beachten Sie, dass das Weglassen des `=` in `git -c foo.bar ...` erlaubt ist und `foo.bar` auf `true` setzt (genau wie `[foo]bar` in einer Konfigurationsdatei). Ein Gleichheitszeichen ohne Wert (wie `git -c foo.bar= ...`) setzt `foo.bar` auf einen leeren String, den `git config --type=bool` in `false` konvertiert.

[](https://git-scm.com/docs/git/de#git---config-envltnamegtltenvvargt)--config-env=<name>=<envvar>

Like `-c <name>=<value>`, give configuration variable _< name>_ a value, where <envvar> is the name of an environment variable from which to retrieve the value. Unlike `-c` there is no shortcut for directly setting the value to an empty string, instead the environment variable itself must be set to the empty string. It is an error if the `<envvar>` does not exist in the environment. `<envvar>` may not contain an equals sign to avoid ambiguity with `<name>` containing one.
This is useful for cases where you want to pass transitory configuration options to git, but are doing so on OS’s where other processes might be able to read your cmdline (e.g. `/proc/self/cmdline`), but not your environ (e.g. `/proc/self/environ`). That behavior is the default on Linux, but may not be on your system.
Note that this might add security for variables such as `http.extraHeader` where the sensitive information is part of the value, but not e.g. `url.<base>.insteadOf` where the sensitive information can be part of the key.

[](https://git-scm.com/docs/git/de#git---exec-pathltPfadgt)--exec-path[=<Pfad>]

Installationspfad Ihrer Git-Programme. Dies kann auch durch Setzen der Umgebungsvariable GIT_EXEC_PATH. Wenn kein Pfad angegeben ist, gibt git die aktuelle Einstellung aus.

[](https://git-scm.com/docs/git/de#git---html-path)--html-path

Ausgabe des Pfads in dem Git’s HTML-Dokumentation installiert ist ohne abschließenden Schrägstrich.

[](https://git-scm.com/docs/git/de#git---man-path)--man-path

Ausgabe des Handbuchpfads (siehe `man(1)`) für die Handbuchseiten für diese Git-Version.

[](https://git-scm.com/docs/git/de#git---info-path)--info-path

Ausgave des Pfads in dem die Info-Dateien die diese Git-Version dokumentieren installiert sind.

[](https://git-scm.com/docs/git/de#git--p)-p


[](https://git-scm.com/docs/git/de#git---paginate)--paginate

Alle Ausgaben an _less_ (oder, falls gesetzt $PAGER) weiterleiten, falls die Standard-Ausgabe ein terminal ist. Dies setzt sich über die `pager.<cmd>` Konfigurationsoptionen hinweg (siehe Abschnitt "Configuration Mechanism" weiter unten).

[](https://git-scm.com/docs/git/de#git--P)-P


[](https://git-scm.com/docs/git/de#git---no-pager)--no-pager

Git-Ausgaben nicht an einen Pager weiterleiten.

[](https://git-scm.com/docs/git/de#git---git-dirltPfadgt)--git-dir=<Pfad>

Set the path to the repository (".git" directory). This can also be controlled by setting the `GIT_DIR` environment variable. It can be an absolute path or relative path to current working directory.
Specifying the location of the ".git" directory using this option (or `GIT_DIR` environment variable) turns off the repository discovery that tries to find a directory with ".git" subdirectory (which is how the repository and the top-level of the working tree are discovered), and tells Git that you are at the top level of the working tree. If you are not at the top-level directory of the working tree, you should tell Git where the top-level of the working tree is, with the `--work-tree=<path>` option (or `GIT_WORK_TREE` environment variable)
If you just want to run git as if it was started in `<path>` then use `git -C <path>`.

[](https://git-scm.com/docs/git/de#git---work-treeltPfadgt)--work-tree=<Pfad>

Set the path to the working tree. It can be an absolute path or a path relative to the current working directory. This can also be controlled by setting the GIT_WORK_TREE environment variable and the core.worktree configuration variable (see core.worktree in [git-config[1]](https://git-scm.com/docs/git-config/de) for a more detailed discussion).

[](https://git-scm.com/docs/git/de#git---namespaceltPfadgt)--namespace=<Pfad>

Setzt den Git Namespace. Siehe [gitnamespaces[7]](https://git-scm.com/docs/gitnamespaces/de) für weitere Details. Dies entspricht dem Setzen der Umgebungsvariable `GIT_NAMESPACE`.

[](https://git-scm.com/docs/git/de#git---super-prefixltPfadgt)--super-prefix=<Pfad>

Currently for internal use only. Set a prefix which gives a path from above a repository down to its root. One use is to give submodules context about the superproject that invoked it.

[](https://git-scm.com/docs/git/de#git---bare)--bare

Das Repository als Bare-Repository behandeln. Wenn die Umgebungsvariable GIT_DIR nicht gestezt ist, wird sie auf das aktuelle Arbeitsverzeichnis gesetzt.

[](https://git-scm.com/docs/git/de#git---no-replace-objects)--no-replace-objects

Do not use replacement refs to replace Git objects. See [git-replace[1]](https://git-scm.com/docs/git-replace/de) for more information.

[](https://git-scm.com/docs/git/de#git---literal-pathspecs)--literal-pathspecs

Pfadspezifikationen buchstäblich (d.h. kein Globbing, keine Pfadspezifikationsangaben) behandeln. Dies entspricht dem Setzen der Umgebungsvariable `GIT_LITERAL_PATHSPECS` auf `1`.

[](https://git-scm.com/docs/git/de#git---glob-pathspecs)--glob-pathspecs

Fügt die Pfadspezifikationsangabe "glob" zu allen Pfadspezifikationen hinzu. Dies entspricht dem Setzen der Umgebungsvariable `GIT_GLOB_PATHSPECS` auf 1. Globbing kann für einzelne Pfadspezifikationen mit der Pfadspezifikationsangabe ":(literal)" deaktiviert werden

[](https://git-scm.com/docs/git/de#git---noglob-pathspecs)--noglob-pathspecs

Fügt die Pfadspezifikationsangabe "literal" zu allen Pfadspezifikationen hinzu. Dies entspricht dem Setzen der Umgebungsvariable `GIT_NOGLOB_PATHSPECS` auf 1. Globbing kann für einzelne Pfadspezifikationen mit der Pfadspezifikationsangabe ":(glob)" aktiviert werden

[](https://git-scm.com/docs/git/de#git---icase-pathspecs)--icase-pathspecs

Fügt die Pfadspezifikationsangabe "icase" zu allen Pfadspezifikationen hinzu. Dies entspricht dem Setzen der Umgebungsvariable `GIT_ICASE_PATHSPECS` auf 1.

[](https://git-scm.com/docs/git/de#git---no-optional-locks)--no-optional-locks

Führt keine optionalen Operationen durch, die Sperren erfordern. Dies entspricht dem Setzen von `GIT_OPTIONAL_LOCKS` auf `0`.

[](https://git-scm.com/docs/git/de#git---list-cmdsGruppeGruppe82308203)--list-cmds=Gruppe[,Gruppe…​]

Befehle nach Gruppe auflisten. Dies ist eine interne/experimentelle Option und könnte in zukunft geändert oder entfernt werden. Unterstützt folgende Gruppen: builtins (Integrierte Befehle), parseopt (Integrierte Befehle, die Parse-Optionen verwenden), main (Alle Befehle im Verzeichnis libexec), others (Alle anderen Befehle in `$PATH` mit Präfix git-), list-<Kategorie> (siehe Kategorien in command-list.txt), nohelpers (Hilfsbefehle ausschließen), alias and config (Befehlsliste aus Konfigurationsvariable completion.commands)
##  [](https://git-scm.com/docs/git/de#_git_befehle)GIT-BEFEHLE
Wir unterteilen Git in hochrangige Befehle ("Porcelain") und Systembefehle ("Plumbing").
##  [](https://git-scm.com/docs/git/de#_hochrangige_befehle_porcelain)Hochrangige Befehle (Porcelain)
Wir unterteilen "Porcelain"-Befehle in Hauptbefehle und zusätzliche Benutzerwerkzeuge.
###  [](https://git-scm.com/docs/git/de#_hauptbefehle)Hauptbefehle

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-adddegit-add1a)[git-add[1]](https://git-scm.com/docs/git-add/de)

Füge Dateiinhalte zum Index hinzu.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-amdegit-am1a)[git-am[1]](https://git-scm.com/docs/git-am/de)

Eine Serie von Patches von einer Mailbox anwenden.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-archivedegit-archive1a)[git-archive[1]](https://git-scm.com/docs/git-archive/de)

Dateiarchiv von angegebenem Verzeichnis erstellen.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-bisectdegit-bisect1a)[git-bisect[1]](https://git-scm.com/docs/git-bisect/de)

Binärsuche verwenden, um den Commit zu finden, der einen Fehler verursacht hat.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-branchdegit-branch1a)[git-branch[1]](https://git-scm.com/docs/git-branch/de)

Branches anzeigen, erstellen oder entfernen.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-bundledegit-bundle1a)[git-bundle[1]](https://git-scm.com/docs/git-bundle/de)

Objekte und Referenzen über ein Archiv verteilen.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-checkoutdegit-checkout1a)[git-checkout[1]](https://git-scm.com/docs/git-checkout/de)

Branches wechseln oder Dateien im Arbeitsverzeichnis wiederherstellen.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-cherry-pickdegit-cherry-pick1a)[git-cherry-pick[1]](https://git-scm.com/docs/git-cherry-pick/de)

Änderungen eines existierenden Commits anwenden.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-citooldegit-citool1a)[git-citool[1]](https://git-scm.com/docs/git-citool/de)

Graphische Alternative zu git-commit.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-cleandegit-clean1a)[git-clean[1]](https://git-scm.com/docs/git-clean/de)

Unversionierte Dateien vom Arbeitsverzeichnis entfernen.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-clonedegit-clone1a)[git-clone[1]](https://git-scm.com/docs/git-clone/de)

Ein Repository in einem neuen Verzeichnis klonen.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-commitdegit-commit1a)[git-commit[1]](https://git-scm.com/docs/git-commit/de)

Änderungen in das Repository eintragen.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-describedegit-describe1a)[git-describe[1]](https://git-scm.com/docs/git-describe/de)

Einem Objekt einen für Menschen lesbaren Namen basierend auf einer verfügbaren Referenz geben.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-diffdegit-diff1a)[git-diff[1]](https://git-scm.com/docs/git-diff/de)

Änderungen zwischen Commits, Commit und Arbeitsverzeichnis, etc. anzeigen.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-fetchdegit-fetch1a)[git-fetch[1]](https://git-scm.com/docs/git-fetch/de)

Objekte und Referenzen von einem anderen Repository herunterladen.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-format-patchdegit-format-patch1a)[git-format-patch[1]](https://git-scm.com/docs/git-format-patch/de)

Patches für E-Mail-Versand vorbereiten.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-gcdegit-gc1a)[git-gc[1]](https://git-scm.com/docs/git-gc/de)

Nicht benötigte Dateien entfernen und das lokale Repository optimieren.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-grepdegit-grep1a)[git-grep[1]](https://git-scm.com/docs/git-grep/de)

Zeilen darstellen, die einem Muster entsprechen.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-guidegit-gui1a)[git-gui[1]](https://git-scm.com/docs/git-gui/de)

Eine portable grafische Schnittstelle zu Git.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-initdegit-init1a)[git-init[1]](https://git-scm.com/docs/git-init/de)

Ein leeres Git-Repository erstellen oder ein bestehendes neuinitialisieren.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-logdegit-log1a)[git-log[1]](https://git-scm.com/docs/git-log/de)

Commit-Historie anzeigen.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-maintenancedegit-maintenance1a)[git-maintenance[1]](https://git-scm.com/docs/git-maintenance/de)

Run tasks to optimize Git repository data.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-mergedegit-merge1a)[git-merge[1]](https://git-scm.com/docs/git-merge/de)

Zwei oder mehr Entwicklungszweige zusammenführen.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-mvdegit-mv1a)[git-mv[1]](https://git-scm.com/docs/git-mv/de)

Eine Datei, ein Verzeichnis oder einen Symlink verschieben oder umbenennen.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-notesdegit-notes1a)[git-notes[1]](https://git-scm.com/docs/git-notes/de)

Objekt-Notizen hinzufügen oder überprüfen.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-pulldegit-pull1a)[git-pull[1]](https://git-scm.com/docs/git-pull/de)

Objekte von einem externen Repository anfordern und sie mit einem anderen Repository oder einem lokalen Branch zusammenführen.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-pushdegit-push1a)[git-push[1]](https://git-scm.com/docs/git-push/de)

Remote-Referenzen mitsamt den verbundenen Objekten aktualisieren.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-range-diffdegit-range-diff1a)[git-range-diff[1]](https://git-scm.com/docs/git-range-diff/de)

Vergleiche zwei Commit-Bereiche (z.B. zwei Versionen eines Branches).

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-rebasedegit-rebase1a)[git-rebase[1]](https://git-scm.com/docs/git-rebase/de)

Wiederholtes Anwenden von Commits auf anderem Basis-Commit.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-resetdegit-reset1a)[git-reset[1]](https://git-scm.com/docs/git-reset/de)

Aktuellen HEAD zu einem spezifizierten Zustand setzen.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-restoredegit-restore1a)[git-restore[1]](https://git-scm.com/docs/git-restore/de)

Dateien im Arbeitsverzeichnis wiederherstellen.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-revertdegit-revert1a)[git-revert[1]](https://git-scm.com/docs/git-revert/de)

Einige bestehende Commits rückgängig machen.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-rmdegit-rm1a)[git-rm[1]](https://git-scm.com/docs/git-rm/de)

Dateien aus dem Arbeitsverzeichnis und dem Index löschen.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-shortlogdegit-shortlog1a)[git-shortlog[1]](https://git-scm.com/docs/git-shortlog/de)

Ausgabe von _git log_ zusammenfassen.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-showdegit-show1a)[git-show[1]](https://git-scm.com/docs/git-show/de)

Verschiedene Arten von Objekten anzeigen.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-sparse-checkoutdegit-sparse-checkout1a)[git-sparse-checkout[1]](https://git-scm.com/docs/git-sparse-checkout/de)

Reduce your working tree to a subset of tracked files.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-stashdegit-stash1a)[git-stash[1]](https://git-scm.com/docs/git-stash/de)

Änderungen in einem Arbeitsverzeichnis aufbewahren.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-statusdegit-status1a)[git-status[1]](https://git-scm.com/docs/git-status/de)

Den Zustand des Arbeitsverzeichnisses anzeigen.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-submoduledegit-submodule1a)[git-submodule[1]](https://git-scm.com/docs/git-submodule/de)

Submodule initialisieren, aktualisieren oder inspizieren.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-switchdegit-switch1a)[git-switch[1]](https://git-scm.com/docs/git-switch/de)

Branches wechseln.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-tagdegit-tag1a)[git-tag[1]](https://git-scm.com/docs/git-tag/de)

Ein mit GPG signiertes Tag-Objekt erzeugen, auflisten, löschen oder verifizieren.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-worktreedegit-worktree1a)[git-worktree[1]](https://git-scm.com/docs/git-worktree/de)

Mehrere Arbeitsverzeichnisse verwalten.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgitkdegitk1a)[gitk[1]](https://git-scm.com/docs/gitk/de)

Der Git-Repository-Browser.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsscalardescalar1a)[scalar[1]](https://git-scm.com/docs/scalar/de)

A tool for managing large Git repositories.
###  [](https://git-scm.com/docs/git/de#_nebenbefehle)Nebenbefehle
Manipulatoren:

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-configdegit-config1a)[git-config[1]](https://git-scm.com/docs/git-config/de)

Repositoryweite oder globale Optionen lesen und setzen.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-fast-exportdegit-fast-export1a)[git-fast-export[1]](https://git-scm.com/docs/git-fast-export/de)

Export-Tool für Git-Daten.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-fast-importdegit-fast-import1a)[git-fast-import[1]](https://git-scm.com/docs/git-fast-import/de)

Backend für schnelle Git-Datenimport-Tools.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-filter-branchdegit-filter-branch1a)[git-filter-branch[1]](https://git-scm.com/docs/git-filter-branch/de)

Branches umschreiben.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-mergetooldegit-mergetool1a)[git-mergetool[1]](https://git-scm.com/docs/git-mergetool/de)

Ausführen von Tools zur Auflösung von Merge-Konflikten zur Behebung dieser.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-pack-refsdegit-pack-refs1a)[git-pack-refs[1]](https://git-scm.com/docs/git-pack-refs/de)

Branches und Tags für effizienten Zugriff auf das Repository packen.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-prunedegit-prune1a)[git-prune[1]](https://git-scm.com/docs/git-prune/de)

Alle nicht erreichbaren Objekte von der Objektdatenbank entfernen.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-reflogdegit-reflog1a)[git-reflog[1]](https://git-scm.com/docs/git-reflog/de)

Reflog-Informationen verwalten.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-refsdegit-refs1a)[git-refs[1]](https://git-scm.com/docs/git-refs/de)

Low-level access to refs.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-remotedegit-remote1a)[git-remote[1]](https://git-scm.com/docs/git-remote/de)

Einen Satz entfernter Repositories verwalten.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-repackdegit-repack1a)[git-repack[1]](https://git-scm.com/docs/git-repack/de)

Ungepackte Objekte in einem Repository packen.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-replacedegit-replace1a)[git-replace[1]](https://git-scm.com/docs/git-replace/de)

Referenzen für ersetzende Objekte erstellen, auflisten, löschen.
Abfragen:

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-annotatedegit-annotate1a)[git-annotate[1]](https://git-scm.com/docs/git-annotate/de)

Zeilen der Datei mit Commit-Informationen versehen und anzeigen.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-blamedegit-blame1a)[git-blame[1]](https://git-scm.com/docs/git-blame/de)

Anzeigen, durch welchen Commit und Autor die jeweiligen Zeilen einer Datei zuletzt geändert wurden.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-bugreportdegit-bugreport1a)[git-bugreport[1]](https://git-scm.com/docs/git-bugreport/de)

Collect information for user to file a bug report.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-count-objectsdegit-count-objects1a)[git-count-objects[1]](https://git-scm.com/docs/git-count-objects/de)

Anzahl und Speicherverbrauch ungepackter Objekte zählen.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-diagnosedegit-diagnose1a)[git-diagnose[1]](https://git-scm.com/docs/git-diagnose/de)

Generate a zip archive of diagnostic information.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-difftooldegit-difftool1a)[git-difftool[1]](https://git-scm.com/docs/git-difftool/de)

Änderungen mittels den allgemeinen Diff-Tools anzeigen.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-fsckdegit-fsck1a)[git-fsck[1]](https://git-scm.com/docs/git-fsck/de)

Stellt die Verbundenheit und Gültigkeit der Objekte in der Datenbank sicher.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-helpdegit-help1a)[git-help[1]](https://git-scm.com/docs/git-help/de)

Hilfsinformationen über Git anzeigen.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-instawebdegit-instaweb1a)[git-instaweb[1]](https://git-scm.com/docs/git-instaweb/de)

Ihr aktuelles Repository sofort in gitweb betrachten.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-merge-treedegit-merge-tree1a)[git-merge-tree[1]](https://git-scm.com/docs/git-merge-tree/de)

Perform merge without touching index or working tree.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-rereredegit-rerere1a)[git-rerere[1]](https://git-scm.com/docs/git-rerere/de)

Aufgezeichnete Auflösung von Merge-Konflikten wiederverwenden.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-show-branchdegit-show-branch1a)[git-show-branch[1]](https://git-scm.com/docs/git-show-branch/de)

Branches und ihre Commits ausgeben.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-verify-commitdegit-verify-commit1a)[git-verify-commit[1]](https://git-scm.com/docs/git-verify-commit/de)

Die GPG-Signatur von Commits prüfen.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-verify-tagdegit-verify-tag1a)[git-verify-tag[1]](https://git-scm.com/docs/git-verify-tag/de)

Die GPG-Signatur von Tags prüfen.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-versiondegit-version1a)[git-version[1]](https://git-scm.com/docs/git-version/de)

Display version information about Git.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-whatchangeddegit-whatchanged1a)[git-whatchanged[1]](https://git-scm.com/docs/git-whatchanged/de)

Show logs with differences each commit introduces.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgitwebdegitweb1a)[gitweb[1]](https://git-scm.com/docs/gitweb/de)

Git Web Interface (Web-Frontend für Git-Repositories).
###  [](https://git-scm.com/docs/git/de#_mit_anderen_interagieren)Mit anderen interagieren
Diese Befehle dienen zum Interagieren mit fremden Versionsverwalungen oder mit anderen Personen über Patch per E-Mail.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-archimportdegit-archimport1a)[git-archimport[1]](https://git-scm.com/docs/git-archimport/de)

Ein GNU-Arch-Repository in Git importieren.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-cvsexportcommitdegit-cvsexportcommit1a)[git-cvsexportcommit[1]](https://git-scm.com/docs/git-cvsexportcommit/de)

Einzelnen Commit zu einem ausgecheckten CVS-Repository exportieren.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-cvsimportdegit-cvsimport1a)[git-cvsimport[1]](https://git-scm.com/docs/git-cvsimport/de)

Ihre Daten aus einem anderen SCM übernehmen.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-cvsserverdegit-cvsserver1a)[git-cvsserver[1]](https://git-scm.com/docs/git-cvsserver/de)

Ein CVS-Server-Emulator für Git.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-imap-senddegit-imap-send1a)[git-imap-send[1]](https://git-scm.com/docs/git-imap-send/de)

Eine Sammlung von Patches von der Standard-Eingabe an einen IMAP-Ordner senden.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-p4degit-p41a)[git-p4[1]](https://git-scm.com/docs/git-p4/de)

Repositories aus Perforce importieren und an diese senden.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-quiltimportdegit-quiltimport1a)[git-quiltimport[1]](https://git-scm.com/docs/git-quiltimport/de)

Patches aus quilt auf aktuellen Branch anwenden.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-request-pulldegit-request-pull1a)[git-request-pull[1]](https://git-scm.com/docs/git-request-pull/de)

Eine Übersicht über ausstehende Änderungen generieren.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-send-emaildegit-send-email1a)[git-send-email[1]](https://git-scm.com/docs/git-send-email/de)

Eine Sammlung von Patches als E-Mails versenden.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-svndegit-svn1a)[git-svn[1]](https://git-scm.com/docs/git-svn/de)

Bidirektionale Operationen zwischen einem Subversion-Repository und Git.
###  [](https://git-scm.com/docs/git/de#_reset_restore_und_revert)Reset, restore und revert
There are three commands with similar names: `git reset`, `git restore` and `git revert`.
  * [git-revert[1]](https://git-scm.com/docs/git-revert/de) is about making a new commit that reverts the changes made by other commits.
  * [git-restore[1]](https://git-scm.com/docs/git-restore/de) is about restoring files in the working tree from either the index or another commit. This command does not update your branch. The command can also be used to restore files in the index from another commit.
  * [git-reset[1]](https://git-scm.com/docs/git-reset/de) is about updating your branch, moving the tip in order to add or remove commits from the branch. This operation changes the commit history.
`git reset` can also be used to restore the index, overlapping with `git restore`.


##  [](https://git-scm.com/docs/git/de#_systembefehle_plumbing)Systembefehle ("Plumbing")
Auch wenn Git eigene hochrangige Befehle enthält, reichen die Systembefehle aus, um alternative hochrangige Befehle zu entwickeln. Entwickler solcher Befehle sollten sich zum Einstieg in [git-update-index[1]](https://git-scm.com/docs/git-update-index/de) und [git-read-tree[1]](https://git-scm.com/docs/git-read-tree/de) einlesen.
Die Schnittstelle (Eingaben, Ausgaben, verfügbare Optionen und Semantik) zu diesen Systembefehlen sollen viel stabiler als "Porcelain"-Befehle sein, da sie hauptsächlich zum Gebrauch in Skripten vorgesehen sind. Bei der Schnittstelle zu "Porcelain"-Befehlen sind dagegen Änderungen zur Verbesserung der Benutzerfreundlichkeit vorbehalten.
Im folgenden Text werden die Systembefehle unterteilt in Befehle um Objekte (in the repository, index, and working tree) zu manipulieren, Befehle um Objekte abzufragen und zu vergleichen und Befehle um Objekte und Referenzen zwischen Repositories zu übertragen.
###  [](https://git-scm.com/docs/git/de#_manipulierende_befehle)Manipulierende Befehle

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-applydegit-apply1a)[git-apply[1]](https://git-scm.com/docs/git-apply/de)

Einen Patch auf Dateien und/oder den Index anwenden.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-checkout-indexdegit-checkout-index1a)[git-checkout-index[1]](https://git-scm.com/docs/git-checkout-index/de)

Dateien von dem Index ins Arbeitsverzeichnis kopieren.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-commit-graphdegit-commit-graph1a)[git-commit-graph[1]](https://git-scm.com/docs/git-commit-graph/de)

Schreibe und verifiziere Git-Commit-Graph-Dateien.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-commit-treedegit-commit-tree1a)[git-commit-tree[1]](https://git-scm.com/docs/git-commit-tree/de)

Ein neues Commit-Objekt erstellen.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-hash-objectdegit-hash-object1a)[git-hash-object[1]](https://git-scm.com/docs/git-hash-object/de)

Compute object ID and optionally create an object from a file.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-index-packdegit-index-pack1a)[git-index-pack[1]](https://git-scm.com/docs/git-index-pack/de)

Pack-Index-Datei für ein existierendes gepacktes Archiv erzeugen.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-merge-filedegit-merge-file1a)[git-merge-file[1]](https://git-scm.com/docs/git-merge-file/de)

Einen 3-Wege-Datei-Merge ausführen.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-merge-indexdegit-merge-index1a)[git-merge-index[1]](https://git-scm.com/docs/git-merge-index/de)

Einen Merge für zusammenzuführende Dateien ausführen.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-mktagdegit-mktag1a)[git-mktag[1]](https://git-scm.com/docs/git-mktag/de)

Creates a tag object with extra validation.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-mktreedegit-mktree1a)[git-mktree[1]](https://git-scm.com/docs/git-mktree/de)

Tree-Objekt aus ls-tree formattiertem Text erzeugen.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-multi-pack-indexdegit-multi-pack-index1a)[git-multi-pack-index[1]](https://git-scm.com/docs/git-multi-pack-index/de)

Schreibe und verifiziere Multipackindizes.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-pack-objectsdegit-pack-objects1a)[git-pack-objects[1]](https://git-scm.com/docs/git-pack-objects/de)

Ein gepacktes Archiv von Objekten erstellen.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-prune-packeddegit-prune-packed1a)[git-prune-packed[1]](https://git-scm.com/docs/git-prune-packed/de)

Zusätzliche Objekte, die sich bereits in Paketdateien befinden, entfernen.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-read-treedegit-read-tree1a)[git-read-tree[1]](https://git-scm.com/docs/git-read-tree/de)

Verzeichnisinformationen in den Index einlesen.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-replaydegit-replay1a)[git-replay[1]](https://git-scm.com/docs/git-replay/de)

EXPERIMENTAL: Replay commits on a new base, works with bare repos too.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-symbolic-refdegit-symbolic-ref1a)[git-symbolic-ref[1]](https://git-scm.com/docs/git-symbolic-ref/de)

Symbolische Referenzen lesen, ändern und löschen.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-unpack-objectsdegit-unpack-objects1a)[git-unpack-objects[1]](https://git-scm.com/docs/git-unpack-objects/de)

Objekte aus einem gepackten Archiv entpacken.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-update-indexdegit-update-index1a)[git-update-index[1]](https://git-scm.com/docs/git-update-index/de)

Dateiinhalte aus dem Arbeitsverzeichnis im Index registrieren.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-update-refdegit-update-ref1a)[git-update-ref[1]](https://git-scm.com/docs/git-update-ref/de)

Den Objektnamen, der in einer Referenz gespeichert ist, sicher aktualisieren.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-write-treedegit-write-tree1a)[git-write-tree[1]](https://git-scm.com/docs/git-write-tree/de)

Tree-Objekt vom aktuellen Index erstellen.
###  [](https://git-scm.com/docs/git/de#_abfragebefehle)Abfragebefehle

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-cat-filedegit-cat-file1a)[git-cat-file[1]](https://git-scm.com/docs/git-cat-file/de)

Provide contents or details of repository objects.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-cherrydegit-cherry1a)[git-cherry[1]](https://git-scm.com/docs/git-cherry/de)

Commits finden, die noch auf dem Upstream-Branch angewendet werden müssen.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-diff-filesdegit-diff-files1a)[git-diff-files[1]](https://git-scm.com/docs/git-diff-files/de)

Dateien von dem Arbeitsverzeichnis und dem Index vergleichen.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-diff-indexdegit-diff-index1a)[git-diff-index[1]](https://git-scm.com/docs/git-diff-index/de)

Ein Verzeichnis von dem Arbeitsverzeichnis und dem Index vergleichen.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-diff-treedegit-diff-tree1a)[git-diff-tree[1]](https://git-scm.com/docs/git-diff-tree/de)

Den Inhalt und Modus von Blobs aus zwei Verzeichnisobjekten vergleichen.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-for-each-refdegit-for-each-ref1a)[git-for-each-ref[1]](https://git-scm.com/docs/git-for-each-ref/de)

Informationen für jede Referenz ausgeben.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-for-each-repodegit-for-each-repo1a)[git-for-each-repo[1]](https://git-scm.com/docs/git-for-each-repo/de)

Run a Git command on a list of repositories.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-get-tar-commit-iddegit-get-tar-commit-id1a)[git-get-tar-commit-id[1]](https://git-scm.com/docs/git-get-tar-commit-id/de)

Commit-ID eines Archivs extrahieren, welches mit git-archive erstellt wurde.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-ls-filesdegit-ls-files1a)[git-ls-files[1]](https://git-scm.com/docs/git-ls-files/de)

Informationen über Dateien in dem Index und im Arbeitsverzeichnis anzeigen.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-ls-remotedegit-ls-remote1a)[git-ls-remote[1]](https://git-scm.com/docs/git-ls-remote/de)

Referenzen in einem Remote-Repository auflisten.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-ls-treedegit-ls-tree1a)[git-ls-tree[1]](https://git-scm.com/docs/git-ls-tree/de)

Inhalte eines Tree-Objektes auflisten.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-merge-basedegit-merge-base1a)[git-merge-base[1]](https://git-scm.com/docs/git-merge-base/de)

Bestmöglichen gemeinsamen Vorgänger-Commit für einen Merge finden.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-name-revdegit-name-rev1a)[git-name-rev[1]](https://git-scm.com/docs/git-name-rev/de)

Symbolische Namen für die gegebenen Commits finden.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-pack-redundantdegit-pack-redundant1a)[git-pack-redundant[1]](https://git-scm.com/docs/git-pack-redundant/de)

Redundante Paketdateien finden.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-rev-listdegit-rev-list1a)[git-rev-list[1]](https://git-scm.com/docs/git-rev-list/de)

Commit-Objekte chronologisch absteigend sortiert auflisten.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-rev-parsedegit-rev-parse1a)[git-rev-parse[1]](https://git-scm.com/docs/git-rev-parse/de)

Parameter herauspicken und ändern.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-show-indexdegit-show-index1a)[git-show-index[1]](https://git-scm.com/docs/git-show-index/de)

Gepackten Archiv-Index anzeigen.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-show-refdegit-show-ref1a)[git-show-ref[1]](https://git-scm.com/docs/git-show-ref/de)

Referenzen in einem lokalen Repository auflisten.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-unpack-filedegit-unpack-file1a)[git-unpack-file[1]](https://git-scm.com/docs/git-unpack-file/de)

Eine temporäre Datei mit den Inhalten eines Blobs erstellen.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-vardegit-var1a)[git-var[1]](https://git-scm.com/docs/git-var/de)

Eine logische Variable von Git anzeigen.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-verify-packdegit-verify-pack1a)[git-verify-pack[1]](https://git-scm.com/docs/git-verify-pack/de)

Gepackte Git-Archivdateien validieren.
Abfragebefehle verändern im Allgemeinen keine Dateien im Arbeitsverzeichnis.
###  [](https://git-scm.com/docs/git/de#_syncing_repositories)Syncing repositories

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-daemondegit-daemon1a)[git-daemon[1]](https://git-scm.com/docs/git-daemon/de)

Ein wirklich einfacher Server für Git Repositories.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-fetch-packdegit-fetch-pack1a)[git-fetch-pack[1]](https://git-scm.com/docs/git-fetch-pack/de)

Fehlende Objekte von einem anderen Repository empfangen.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-http-backenddegit-http-backend1a)[git-http-backend[1]](https://git-scm.com/docs/git-http-backend/de)

Serverseitige Implementierung von Git über HTTP.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-send-packdegit-send-pack1a)[git-send-pack[1]](https://git-scm.com/docs/git-send-pack/de)

Objekte über das Git Protokoll zu einem anderen Repository übertragen.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-update-server-infodegit-update-server-info1a)[git-update-server-info[1]](https://git-scm.com/docs/git-update-server-info/de)

Hilfsinformationsdatei zur Hilfe von einfachen Servern aktualisieren.
Die folgenden Befehle sind Hilfsbefehle für die oben genannten Befehle; Endbenutzer rufen sie normalerweise nicht direkt auf.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-http-fetchdegit-http-fetch1a)[git-http-fetch[1]](https://git-scm.com/docs/git-http-fetch/de)

Von einem Remote-Git-Repository über HTTP herunterladen.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-http-pushdegit-http-push1a)[git-http-push[1]](https://git-scm.com/docs/git-http-push/de)

Objekte über HTTP/DAV zu einem anderen Repository übertragen.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-receive-packdegit-receive-pack1a)[git-receive-pack[1]](https://git-scm.com/docs/git-receive-pack/de)

Empfangen was in das Repository übertragen wurde.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-shelldegit-shell1a)[git-shell[1]](https://git-scm.com/docs/git-shell/de)

Login-Shell beschränkt für Nur-Git SSH-Zugriff.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-upload-archivedegit-upload-archive1a)[git-upload-archive[1]](https://git-scm.com/docs/git-upload-archive/de)

Archiv zurück zu git-archive senden.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-upload-packdegit-upload-pack1a)[git-upload-pack[1]](https://git-scm.com/docs/git-upload-pack/de)

Objekte gepackt zurück an git-fetch-pack senden.
###  [](https://git-scm.com/docs/git/de#_interne_hilfsbefehle)Interne Hilfsbefehle
Diese Befehle sind Hilfsbefehle für die andere Befehle; Endbenutzer rufen sie normalerweise nicht direkt auf.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-check-attrdegit-check-attr1a)[git-check-attr[1]](https://git-scm.com/docs/git-check-attr/de)

gitattributes-Informationen darstellen.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-check-ignoredegit-check-ignore1a)[git-check-ignore[1]](https://git-scm.com/docs/git-check-ignore/de)

Fehlersuche in gitignore- / exclude-Dateien.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-check-mailmapdegit-check-mailmap1a)[git-check-mailmap[1]](https://git-scm.com/docs/git-check-mailmap/de)

Name und E-Mail-Adresse von Kontakten anzeigen.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-check-ref-formatdegit-check-ref-format1a)[git-check-ref-format[1]](https://git-scm.com/docs/git-check-ref-format/de)

Sicherstellen, dass ein Referenzname wohlgeformt ist.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-columndegit-column1a)[git-column[1]](https://git-scm.com/docs/git-column/de)

Daten in Spalten anzeigen.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-credentialdegit-credential1a)[git-credential[1]](https://git-scm.com/docs/git-credential/de)

Zugangsdaten des Benutzers abrufen und speichern.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-credential-cachedegit-credential-cache1a)[git-credential-cache[1]](https://git-scm.com/docs/git-credential-cache/de)

Hilfsprogramm zum temporären Speichern von Zugangsdaten im Hauptspeicher.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-credential-storedegit-credential-store1a)[git-credential-store[1]](https://git-scm.com/docs/git-credential-store/de)

Hilfsprogramm zum Speichern von Zugangsdaten auf der Festplatte.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-fmt-merge-msgdegit-fmt-merge-msg1a)[git-fmt-merge-msg[1]](https://git-scm.com/docs/git-fmt-merge-msg/de)

Beschreibung eines Merge-Commits erzeugen.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-hookdegit-hook1a)[git-hook[1]](https://git-scm.com/docs/git-hook/de)

Run git hooks.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-interpret-trailersdegit-interpret-trailers1a)[git-interpret-trailers[1]](https://git-scm.com/docs/git-interpret-trailers/de)

Strukturierte Informationen in Commit-Beschreibungen hinzufügen oder parsen.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-mailinfodegit-mailinfo1a)[git-mailinfo[1]](https://git-scm.com/docs/git-mailinfo/de)

Patch und Urheberschaft aus einer einzelnen E-Mail-Nachricht extrahieren.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-mailsplitdegit-mailsplit1a)[git-mailsplit[1]](https://git-scm.com/docs/git-mailsplit/de)

Einfaches UNIX mbox Splitter-Programm.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-merge-one-filedegit-merge-one-file1a)[git-merge-one-file[1]](https://git-scm.com/docs/git-merge-one-file/de)

Das Standard-Hilfsprogramm für die Verwendung mit git-merge-index.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-patch-iddegit-patch-id1a)[git-patch-id[1]](https://git-scm.com/docs/git-patch-id/de)

Eindeutige ID für einen Patch berechnen.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-sh-i18ndegit-sh-i18n1a)[git-sh-i18n[1]](https://git-scm.com/docs/git-sh-i18n/de)

Git’s i18n-Konfigurationscode für Shell-Skripte.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-sh-setupdegit-sh-setup1a)[git-sh-setup[1]](https://git-scm.com/docs/git-sh-setup/de)

Allgemeiner Git Shell-Skript Konfigurationscode.

[](https://git-scm.com/docs/git/de#git-ahrefrelurldocsgit-stripspacedegit-stripspace1a)[git-stripspace[1]](https://git-scm.com/docs/git-stripspace/de)

Nicht erforderlichen Whitespace entfernen.
##  [](https://git-scm.com/docs/git/de#_guides)Guides
The following documentation pages are guides about Git concepts.
Warning |  Missing `de/cmds-guide.txt` See original version for this content.
---|---
##  [](https://git-scm.com/docs/git/de#_repository_command_and_file_interfaces)Repository, command and file interfaces
This documentation discusses repository and command interfaces which users are expected to interact with directly. See `--user-formats` in [git-help[1]](https://git-scm.com/docs/git-help/de) for more details on the critera.
Warning |  Missing `de/cmds-userinterfaces.txt` See original version for this content.
---|---
##  [](https://git-scm.com/docs/git/de#_file_formats_protocols_and_other_developer_interfaces)File formats, protocols and other developer interfaces
This documentation discusses file formats, over-the-wire protocols and other git developer interfaces. See `--developer-interfaces` in [git-help[1]](https://git-scm.com/docs/git-help/de).
Warning |  Missing `de/cmds-developerinterfaces.txt` See original version for this content.
---|---
##  [](https://git-scm.com/docs/git/de#_konfigurationsmechanismus)Konfigurationsmechanismus
Git nutzt ein einfaches Textformat um Einstellungen pro Benutzer und Repository zu speichern. So eine Konfigurationsdatei kann wie folgt aussehen:
```
#
# Eine Raute '#' oder ein Semikolon ';' markiert # einen Kommentar.
#

; Kernvariablen
[core]
	; den Dateimodi nicht vertrauen
	filemode = false

; Identät des Nutzers
[user]
	name = "Junio C Hamano"
	email = "gitster@pobox.com"
```

Verschiedene Git-Befehle lesen die Konfigurationsdatei und passen ihr Verhalten entsprechend an. Siehe [git-config[1]](https://git-scm.com/docs/git-config/de) für eine Liste der Optionen und mehr Details über den Konfigurationsmechanismus.
##  [](https://git-scm.com/docs/git/de#_bezeichner_terminologie)Bezeichner-Terminologie

[](https://git-scm.com/docs/git/de#git-ltObjektgt)<Objekt>

Bezeichnet den Namen eines Objekts beliebigen Typs.

[](https://git-scm.com/docs/git/de#git-ltBlobgt)<Blob>

Bezeichnet den Namen eines Blob-Objekts.

[](https://git-scm.com/docs/git/de#git-ltTreegt)<Tree>

Bezeichnet den Namen eines Tree-Objekts.

[](https://git-scm.com/docs/git/de#git-ltCommitgt)<Commit>

Bezeichnet den Namen eines Commit-Objekts.

[](https://git-scm.com/docs/git/de#git-ltCommit-Referenzgt)<Commit-Referenz>

Bezeichnet den Namen eines Tree-, Commit- oder Markierungs-Objekts. Ein Befehl, der eine <Commit-Referenz> als Argument akzeptiert arbeitet letztendlich mit einem <Tree>-Objekt, dereferenziert aber auch automatisch <Commit>- und <Markierung>-Objekte, die auf einen <Tree> verweisen.

[](https://git-scm.com/docs/git/de#git-ltCommit-Angabegt)<Commit-Angabe>

Bezeichnet den Namen eines Commit- oder Markierungs-Objekts. Ein Befehl, der eine <Commit-Angabe> als Argument akzeptiert arbeitet letztendlich mit einem <Commit>-Objekt, dereferenziert aber auch automatisch <Markierung>-Objekte, die auf einen <Commit> verweisen.

[](https://git-scm.com/docs/git/de#git-ltArtgt)<Art>

Gibt an, dass eine Objekt-Art benötigt wird. Momentan sind möglich: `blob`, `tree`, `commit` oder `tag` (Markierung).

[](https://git-scm.com/docs/git/de#git-ltDateigt)<Datei>

Bezeichnet einen Dateinamen, der fast immer relativ zur Verzeichnisstruktur in `GIT_INDEX_FILE` ist.
##  [](https://git-scm.com/docs/git/de#_symbolische_bezeichner)Symbolische Bezeichner
Jeder Git-Befehl der ein beliebiges <Objekt> akzeptiert kann auch die folgende symbolische Notation verwenden:

[](https://git-scm.com/docs/git/de#git-HEAD)HEAD

Bezeichnet die Spitze des aktuellen Entwicklungszweigs.

[](https://git-scm.com/docs/git/de#git-ltMarkierunggt)<Markierung>

Eine gültige Markierungsbezeichnung (d.h. ein `refs/tags/<Markierung>` Verweis).

[](https://git-scm.com/docs/git/de#git-ltBranchgt)<Branch>

Eine gültige Branch-Bezeichnung (d.h. ein `refs/heads/<Branch>` Verweis).
Für eine umfänglichere Auflistung wie Objektbezeichnungen angegeben werden können siehe den Abschnitt "REVISIONEN ANGEBEN" in [gitrevisions[7]](https://git-scm.com/docs/gitrevisions/de).
##  [](https://git-scm.com/docs/git/de#_datei_verzeichnisstruktur)Datei-/Verzeichnisstruktur
Siehe das Dokument [gitrepository-layout[5]](https://git-scm.com/docs/gitrepository-layout/de).
Lesen Sie [githooks[5]](https://git-scm.com/docs/githooks/de) für mehr Details über die einzelnen Hooks.
Übergeordnete SCMs können zusätzliche Informationen im `$GIT_DIR` bereitstellen und verwalten.
##  [](https://git-scm.com/docs/git/de#_terminologie)Terminologie
Siehe [gitglossary[7]](https://git-scm.com/docs/gitglossary/de).
##  [](https://git-scm.com/docs/git/de#_umgebungsvariablen)Umgebungsvariablen
Verschiedene Git-Befehle benutzen die folgenden Umgebungsvariablen:
###  [](https://git-scm.com/docs/git/de#_das_git_repository)Das Git-Repository
These environment variables apply to _all_ core Git commands. Nb: it is worth noting that they may be used/overridden by SCMS sitting above Git so take care if using a foreign front-end.

[](https://git-scm.com/docs/git/de#git-codeGITINDEXFILEcode)`GIT_INDEX_FILE`

Diese Umgebungsvariable erlaubt es eine alternative Indexdatei anzugeben. Andernfalls wird die Standarddatei `$GIT_DIR/index` verwendet.

[](https://git-scm.com/docs/git/de#git-codeGITINDEXVERSIONcode)`GIT_INDEX_VERSION`

Mit dieser Umgebungsvariable kann die Indexversion für neue Repositories. Dies hat keine Auswirkung auf bestehende Indexdateien. Standardmäßig wird Indexversion 2 oder 3 verwendet. Siehe [git-update-index[1]](https://git-scm.com/docs/git-update-index/de) für weitere Informationen.

[](https://git-scm.com/docs/git/de#git-codeGITOBJECTDIRECTORYcode)`GIT_OBJECT_DIRECTORY`

Wenn das Objektverzeichnis über diese Umgebungsvariable angegeben wird werden die SHA1-Verzeichnisse darunter angelegt, ansonsten wird standardmäßig Das Verzeichnis`$GIT_DIR/objects` verwendet.

[](https://git-scm.com/docs/git/de#git-codeGITALTERNATEOBJECTDIRECTORIEScode)`GIT_ALTERNATE_OBJECT_DIRECTORIES`

Durch die unveränderliche Natur von Git-Objekten können alte Objekte in gemeinsame schreibgeschützte Verzeichnisse archiviert werden. Diese Variable gibt eine mit ":" (";" unter Windows) getrennte Liste von Objektverzeichnissen, in denen nach Git-Objekten gesucht werden kann, an. Neue Objekte werden nicht in diese Verzeichnisse geschrieben.
Einträge, die mit `"` (doppelten Anführungszeichen) beginnen werden wie Zeichenketten in C interpretiert, d.h. führende und abschließende doppelte Anführungszeichen werden entfernt und Rückwärtsschrägstrich-basierte Escape-Sequenzen werden respektiert. D.h. der Wert `"Pfad-mit-\"-und-:-im-Pfad":Standard-Pfad` enthält zwei Pfade: `"Pfad-mit-"-und-:-im-Pfad` und `Standard-Pfad`.

[](https://git-scm.com/docs/git/de#git-codeGITDIRcode)`GIT_DIR`

Wenn die Umgebungsvariable `GIT_DIR` gesetzt ist, gibt sie den Pfad an, der statt `.git` als Basis des Repositories verwendet wird. Die Befehlszeilenoption `--git-dir` setzt diesen Wert auch.

[](https://git-scm.com/docs/git/de#git-codeGITWORKTREEcode)`GIT_WORK_TREE`

Set the path to the root of the working tree. This can also be controlled by the `--work-tree` command-line option and the core.worktree configuration variable.

[](https://git-scm.com/docs/git/de#git-codeGITNAMESPACEcode)`GIT_NAMESPACE`

Setzt den Git Namespace; Siehe [gitnamespaces[7]](https://git-scm.com/docs/gitnamespaces/de) für Details. Die Befehlszeilenoption `--namespace` setzt diesen Wert auch.

[](https://git-scm.com/docs/git/de#git-codeGITCEILINGDIRECTORIEScode)`GIT_CEILING_DIRECTORIES`

This should be a colon-separated list of absolute paths. If set, it is a list of directories that Git should not chdir up into while looking for a repository directory (useful for excluding slow-loading network directories). It will not exclude the current working directory or a GIT_DIR set on the command line or in the environment. Normally, Git has to read the entries in this list and resolve any symlink that might be present in order to compare them with the current directory. However, if even this access is slow, you can add an empty entry to the list to tell Git that the subsequent entries are not symlinks and needn’t be resolved; e.g., `GIT_CEILING_DIRECTORIES=/maybe/symlink::/very/slow/non/symlink`.

[](https://git-scm.com/docs/git/de#git-codeGITDISCOVERYACROSSFILESYSTEMcode)`GIT_DISCOVERY_ACROSS_FILESYSTEM`

When run in a directory that does not have ".git" repository directory, Git tries to find such a directory in the parent directories to find the top of the working tree, but by default it does not cross filesystem boundaries. This environment variable can be set to true to tell Git not to stop at filesystem boundaries. Like `GIT_CEILING_DIRECTORIES`, this will not affect an explicit repository directory set via `GIT_DIR` or on the command line.

[](https://git-scm.com/docs/git/de#git-codeGITCOMMONDIRcode)`GIT_COMMON_DIR`

Wenn diese Variable einen Pfad enthält, werden nicht-Arbeitsverzeichnis-Dateien, die sich normalerweise in $GIT_DIR befinden stattdessen aus diesem Verzeichnis geladen. Arbeitsverzeichnis-spezifische Dateien wie HEAD oder index werden aus $GIT_DIR geladen. Siehe [gitrepository-layout[5]](https://git-scm.com/docs/gitrepository-layout/de) und [git-worktree[1]](https://git-scm.com/docs/git-worktree/de) für Details. Andere Pfadvariablen wie GIT_INDEX_FILE, GIT_OBJECT_DIRECTORY, etc. haben Vorrang gegenüber dieser Variable.

[](https://git-scm.com/docs/git/de#git-codeGITDEFAULTHASHcode)`GIT_DEFAULT_HASH`

If this variable is set, the default hash algorithm for new repositories will be set to this value. This value is currently ignored when cloning; the setting of the remote repository is used instead. The default is "sha1". THIS VARIABLE IS EXPERIMENTAL! See `--object-format` in [git-init[1]](https://git-scm.com/docs/git-init/de).
###  [](https://git-scm.com/docs/git/de#_git_commits)Git-Commits

[](https://git-scm.com/docs/git/de#git-codeGITAUTHORNAMEcode)`GIT_AUTHOR_NAME`

The human-readable name used in the author identity when creating commit or tag objects, or when writing reflogs. Overrides the `user.name` and `author.name` configuration settings.

[](https://git-scm.com/docs/git/de#git-codeGITAUTHOREMAILcode)`GIT_AUTHOR_EMAIL`

The email address used in the author identity when creating commit or tag objects, or when writing reflogs. Overrides the `user.email` and `author.email` configuration settings.

[](https://git-scm.com/docs/git/de#git-codeGITAUTHORDATEcode)`GIT_AUTHOR_DATE`

The date used for the author identity when creating commit or tag objects, or when writing reflogs. See [git-commit[1]](https://git-scm.com/docs/git-commit/de) for valid formats.

[](https://git-scm.com/docs/git/de#git-codeGITCOMMITTERNAMEcode)`GIT_COMMITTER_NAME`

The human-readable name used in the committer identity when creating commit or tag objects, or when writing reflogs. Overrides the `user.name` and `committer.name` configuration settings.

[](https://git-scm.com/docs/git/de#git-codeGITCOMMITTEREMAILcode)`GIT_COMMITTER_EMAIL`

The email address used in the author identity when creating commit or tag objects, or when writing reflogs. Overrides the `user.email` and `committer.email` configuration settings.

[](https://git-scm.com/docs/git/de#git-codeGITCOMMITTERDATEcode)`GIT_COMMITTER_DATE`

The date used for the committer identity when creating commit or tag objects, or when writing reflogs. See [git-commit[1]](https://git-scm.com/docs/git-commit/de) for valid formats.

[](https://git-scm.com/docs/git/de#git-codeEMAILcode)`EMAIL`

The email address used in the author and committer identities if no other relevant environment variable or configuration setting has been set.
###  [](https://git-scm.com/docs/git/de#_git_diffs)Git-Diffs

[](https://git-scm.com/docs/git/de#git-codeGITDIFFOPTScode)`GIT_DIFF_OPTS`

Die einziegen gültigen Werte sind "--unified=??" oder "-u??" um die Anzahl der angezeigten Kontextzeilen zu steuern, wenn ein vereinheitlichtes Diff erstellt wird. Dies hat Vorrang vor jeglichen auf der Kommandozeile an git diff übergebenen Werten der Optionen "-U" oder "--unified".

[](https://git-scm.com/docs/git/de#git-codeGITEXTERNALDIFFcode)`GIT_EXTERNAL_DIFF`

When the environment variable `GIT_EXTERNAL_DIFF` is set, the program named by it is called to generate diffs, and Git does not use its builtin diff machinery. For a path that is added, removed, or modified, `GIT_EXTERNAL_DIFF` is called with 7 parameters:
```
Pfad alte-Datei alter-Hash alte-Rechte neue-Datei neuer-Hash neue-Rechte
```

wobei:

[](https://git-scm.com/docs/git/de#git-ltalteneuegt-Datei)<alte|neue>-Datei

are files GIT_EXTERNAL_DIFF can use to read the contents of <old|new>,

[](https://git-scm.com/docs/git/de#git-ltalterneuergt-Hash)<alter|neuer>-Hash

die 40-stelligen hexadezimalen Hashes sind,

[](https://git-scm.com/docs/git/de#git-ltalteneuegt-Rechte)<alte|neue>-Rechte

die oktale Representation der Datei-Rechte sind.
Die Dateiparameter können auf die Arbeitsdatei des Benutzers (z.B. `neue-Datei` in "git-diff-files"), `/dev/null` (z.B. `alte-Datei` wenn eine neue Datei hinzugefügt wird) oder eine temporäre Datei (z.B. `alte-Datei` im Index) verweisen. `GIT_EXTERNAL_DIFF` muss sich nicht damit befassen die temporäre Datei zu löschen. --- sie wird entfernt sobald `GIT_EXTERNAL_DIFF` beendet wird.
Für einen nicht zusammengeführten Pfad wird `GIT_EXTERNAL_DIFF` mit einem Parameter, <Pfad>, aufgerufen.
Für jeden Pfad mit dem `GIT_EXTERNAL_DIFF` aufgerufen wird, werden die beiden Umgebungsvariablen `GIT_DIFF_PATH_COUNTER` und `GIT_DIFF_PATH_TOTAL` gesetzt.

[](https://git-scm.com/docs/git/de#git-codeGITDIFFPATHCOUNTERcode)`GIT_DIFF_PATH_COUNTER`

Ein 1-basierter Zähler, der für jeden Pfad um eins inkrementiert wird.

[](https://git-scm.com/docs/git/de#git-codeGITDIFFPATHTOTALcode)`GIT_DIFF_PATH_TOTAL`

Die Gesamtanzahl Pfade.
###  [](https://git-scm.com/docs/git/de#_sonstiges)Sonstiges

[](https://git-scm.com/docs/git/de#git-codeGITMERGEVERBOSITYcode)`GIT_MERGE_VERBOSITY`

Eine numerische Angabe, die Ausgabemenge der rekursiven Merge-Strategie steuert. Überschreibt merge.verbosity. Siehe [git-merge[1]](https://git-scm.com/docs/git-merge/de)

[](https://git-scm.com/docs/git/de#git-codeGITPAGERcode)`GIT_PAGER`

Diese Umgebungsvariable überschreibt `$PAGER`. Wenn sie auf eine leere Zeichenkette oder "cat" gesetzt ist, startet Git keinen Pager. Siehe auch die Option `core.pager` in [git-config[1]](https://git-scm.com/docs/git-config/de).

[](https://git-scm.com/docs/git/de#git-codeGITPROGRESSDELAYcode)`GIT_PROGRESS_DELAY`

A number controlling how many seconds to delay before showing optional progress indicators. Defaults to 2.

[](https://git-scm.com/docs/git/de#git-codeGITEDITORcode)`GIT_EDITOR`

Diese Umgebungsvariable überschreibt `$EDITOR` und `$VISUAL`. Sie wird von mehreren Git-Befehlen verwendet, um im interaktiven Modus einen Editor zu öffnen. Siehe auch [git-var[1]](https://git-scm.com/docs/git-var/de) und die Option `core.editor` in [git-config[1]](https://git-scm.com/docs/git-config/de).

[](https://git-scm.com/docs/git/de#git-codeGITSEQUENCEEDITORcode)`GIT_SEQUENCE_EDITOR`

This environment variable overrides the configured Git editor when editing the todo list of an interactive rebase. See also [git-rebase[1]](https://git-scm.com/docs/git-rebase/de) and the `sequence.editor` option in [git-config[1]](https://git-scm.com/docs/git-config/de).

[](https://git-scm.com/docs/git/de#git-codeGITSSHcode)`GIT_SSH`


[](https://git-scm.com/docs/git/de#git-codeGITSSHCOMMANDcode)`GIT_SSH_COMMAND`

Wenn eine dieser Umgebungsvariablen gesetzt ist, verwenden _git fetch_ und _git push_ den angegebenen Befehl statt _ssh_ zum Verbinden mit entfernten Systemen. Die Kommandozeilenparameter die dem konfigurierten Befehl übergeben werden, richten sich nach der SSH-Varinate. Siehe die Option `ssh.variant` in [git-config[1]](https://git-scm.com/docs/git-config/de) für Details.
`$GIT_SSH_COMMAND` hat Vorrang über `$GIT_SSH` und wird von der Shell interpretiert, daher können zusätzliche Argumente mit angegeben werden. `GIT_SSH` dagegen darf nur den Pfad zu einem Programm enthalten (dieses kann ein Wrapper-Shell-Script sein, falls zusätzliche Argumente benötigt werden).
Meistens ist es einfacher die gewünschten Optionen über Ihre persönliche `.shh/config`-Datei zu konfigurieren. Bitte konsultieren Sie Ihre SSH-Dokumentation für weitere Details.

[](https://git-scm.com/docs/git/de#git-codeGITSSHVARIANTcode)`GIT_SSH_VARIANT`

Wenn diese Umgebungsvariable gesetzt ist, überschreibt sie Git’s automatische Erkennung ob sich `GIT_SSH`/`GIT_SSH_COMMAND`/`core.sshCommand` auf OpenSSH, plink oder tortoiseplink bezieht. Diese Variable überschreibt sie die Konfigurationseinstellung `ssh.variant` die den selben Zweck erfüllt.

[](https://git-scm.com/docs/git/de#git-codeGITASKPASScode)`GIT_ASKPASS`

Wenn diese Umgebungsvariable gesetzt ist, rufen Git-Befehle die Passwörter benötigten (z.B. für HTTP- oder IMAP-Authentifizierung) dieses Programm mit geeigneten Kommandozeilenparametern auf und lesen das Passwort von seiner Standardausgabe. Siehe auch die Option `core.askPass` in [git-config[1]](https://git-scm.com/docs/git-config/de).

[](https://git-scm.com/docs/git/de#git-codeGITTERMINALPROMPTcode)`GIT_TERMINAL_PROMPT`

Wenn diese Umgebungsvariable auf `0` gesetzt ist, fragt Git nicht nach Eingaben im Terminal (z.B. zur HTTP-Authentifizierung).

[](https://git-scm.com/docs/git/de#git-codeGITCONFIGGLOBALcode)`GIT_CONFIG_GLOBAL`


[](https://git-scm.com/docs/git/de#git-codeGITCONFIGSYSTEMcode)`GIT_CONFIG_SYSTEM`

Take the configuration from the given files instead from global or system-level configuration files. If `GIT_CONFIG_SYSTEM` is set, the system config file defined at build time (usually `/etc/gitconfig`) will not be read. Likewise, if `GIT_CONFIG_GLOBAL` is set, neither `$HOME/.gitconfig` nor `$XDG_CONFIG_HOME/git/config` will be read. Can be set to `/dev/null` to skip reading configuration files of the respective level.

[](https://git-scm.com/docs/git/de#git-codeGITCONFIGNOSYSTEMcode)`GIT_CONFIG_NOSYSTEM`

Gibt an, ob das Auslesen der Systemweiten Konfigurationsdatei `$(prefix)/etc/gitconfig` übersprungen wird. Diese Umgebungsvariable kann in Kombination mit `$HOME` und `$XDG_CONFIG_HOME` genutzt werden um eine reproduzierbare Umgebung für ein Skript herzustellen oder um eine fehlerhafte `/etc/gitconfig`-Datei vorübergehend zu vermeiden, während man auf jemanden mit den nötigen Berechtigungen um die Fehler zu beheben wartet.

[](https://git-scm.com/docs/git/de#git-codeGITFLUSHcode)`GIT_FLUSH`

Wenn diese Umgebungsvariable auf 1 gesetzt ist, erzwingen Befehle wie _git blame_ (im inkrementellen Modus),_git rev-list_ ,_git log_ , _git check-attr_ und _git check-ignore_ ein Leeren des Ausgabestroms nach jedem Datensatz. Wenn diese Variable auf "0" gesetzt ist, wird die Ausgabe dieser Befehle mit vollständig gepuffertem I/O durchgeführt. Wenn diese Umgebungsvariable nicht gesetzt ist, wählt Git zwischen gepufferter oder datensatzbasierter Ausgabe basierend darauf, ob stdout in eine Datei umgeleitet zu sein scheint oder nicht.

[](https://git-scm.com/docs/git/de#git-codeGITTRACEcode)`GIT_TRACE`

Aktiviert allgemeine Ablaufverfolgungsmeldungen, z.B.. Alias-Erweiterung, Ausführung von eingebauten und externen Befehlen.
Wenn diese Variable auf "1", "2" oder "true" (Vergleich ist unabhängig von Groß-/Kleinschreibung) gesetzt ist, werden Ablaufverfolgungsmeldungen nach stderr ausgegeben.
Wenn dieser Variable ein ganzzahliger Wert größer als 2 und kleiner als 10 zugewiesen ist, interpretiert Git diesen Wert als geöffneten Datei-Handle und versucht die Ablaufverfolgungsmeldungen in diese Datei zu schreiben.
Alternativ kann diese Variable auf einen absoluten Pfad (beginnt mit einem _/_), schreibt Git die Ablaufverfolgungsmeldungen in diese Datei.
Zurücksetzen der Variable oder setzen auf einen leeren Wert, "0" oder "false" (unabhängig von Groß-/Kleinschreibung) deaktiviert Ablaufverfolgungsmeldungen.

[](https://git-scm.com/docs/git/de#git-codeGITTRACEFSMONITORcode)`GIT_TRACE_FSMONITOR`

Aktiviert Ablaufverfolgungsmeldungen für die Dateisystemmonitor-Erweiterung. Siehe `GIT_TRACE?` für verfügbare Ausgabemöglichkeiten.

[](https://git-scm.com/docs/git/de#git-codeGITTRACEPACKACCESScode)`GIT_TRACE_PACK_ACCESS`

Aktiviert Ablaufverfolgungsmeldungen für Zugriffe auf Pakete. Für jeden Zugriff werden der Name der Paketdatei und ein Offset im Paket aufgezeichnet. Dies kann bei der Fehlersuche bei packetbezogenen Performance-Problemen hilfreich sein. Siehe `GIT_TRACE` für verfügbare Ablaufverfolgungsoptionen.

[](https://git-scm.com/docs/git/de#git-codeGITTRACEPACKETcode)`GIT_TRACE_PACKET`

Aktiviert Ablaufverfolgungsmeldungen für alle Pakete, die in und aus einem bestimmten Programm kommen. Dies kann bei der Suche nach Problemen mit der Objektaushandlung oder anderen protokollbezogenen Problemen. Die Ablaufverfolgung wird bei Packeten, die mit pack beginnen deaktiviert (Siehe hierzu `GIT_TRACE_PACKFILE`). Siehe `GIT_TRACE` für verfügbare Ablaufverfolgungsoptionen.

[](https://git-scm.com/docs/git/de#git-codeGITTRACEPACKFILEcode)`GIT_TRACE_PACKFILE`

Aktiviert die Ablaufverfolgung von gesendeten und empfangenen Packdateien eines bestimmten Programms. Im Gegensatz zu anderen Ablaufverfolgungsmeldungen ist diese Ablaufverfolgung wortgetreu: Keine Kopfzeilen und keine Umwandlung von binären Daten. Sie wollen diese Daten höchstwahrscheinlich in eine Datei umleiten (z.B. `GIT_TRACE_PACKFILE=/tmp/my.pack`), statt sie auf die Konsole auszugeben oder mit anderen Ablaufverfolgungsmeldungen zu vermischen.
Dies ist momentan nur für die Client-Seite der Befehle clone und fetch implementiert.

[](https://git-scm.com/docs/git/de#git-codeGITTRACEPERFORMANCEcode)`GIT_TRACE_PERFORMANCE`

Aktiviert performancebezogene Ablaufverfolgungsmeldungen, z.B. gesamte Ausführunszeit jedes Git-Befehls. Siehe `GIT_TRACE` für verfügbare Ablaufverfolgungsoptionen.

[](https://git-scm.com/docs/git/de#git-codeGITTRACEREFScode)`GIT_TRACE_REFS`

Enables trace messages for operations on the ref database. See `GIT_TRACE` for available trace output options.

[](https://git-scm.com/docs/git/de#git-codeGITTRACESETUPcode)`GIT_TRACE_SETUP`

Enables trace messages printing the .git, working tree and current working directory after Git has completed its setup phase. See `GIT_TRACE` for available trace output options.

[](https://git-scm.com/docs/git/de#git-codeGITTRACESHALLOWcode)`GIT_TRACE_SHALLOW`

Aktiviert Ablaufverfolgungsmeldungen die zur Fehlersuche beim Anfordern (fetching)/Klonen von Repositories mit unvollständiger Historie (shallow) helfen können. Siehe `GIT_TRACE` für verfügbare Ablaufverfolgungsoptionen.

[](https://git-scm.com/docs/git/de#git-codeGITTRACECURLcode)`GIT_TRACE_CURL`

Enables a curl full trace dump of all incoming and outgoing data, including descriptive information, of the git transport protocol. This is similar to doing curl `--trace-ascii` on the command line. See `GIT_TRACE` for available trace output options.

[](https://git-scm.com/docs/git/de#git-codeGITTRACECURLNODATAcode)`GIT_TRACE_CURL_NO_DATA`

Falls Curl-Ablaufverfolgung aktiviert ist (sieh `GIT_TRACE_CURL` oben), keine Nutzdaten, sondern nur Header und Info-Zeilen ausgegeben.

[](https://git-scm.com/docs/git/de#git-codeGITTRACE2code)`GIT_TRACE2`

Enables more detailed trace messages from the "trace2" library. Output from `GIT_TRACE2` is a simple text-based format for human readability.
Wenn diese Variable auf "1", "2" oder "true" (Vergleich ist unabhängig von Groß-/Kleinschreibung) gesetzt ist, werden Ablaufverfolgungsmeldungen nach stderr ausgegeben.
Wenn dieser Variable ein ganzzahliger Wert größer als 2 und kleiner als 10 zugewiesen ist, interpretiert Git diesen Wert als geöffneten Datei-Handle und versucht die Ablaufverfolgungsmeldungen in diese Datei zu schreiben.
Alternativ kann diese Variable auf einen absoluten Pfad (beginnt mit einem _/_), schreibt Git die Ablaufverfolgungsmeldungen in diese Datei. Falls der Pfad ein existierendes Verzeichnis ist, werden die Ablaufverfolgungsmeldungen in Dateien (eine pro Prozess), benannt nach dem letzten Teils der SID und einem optionalen Zähler (um Datienamenskollisionen zu vermeiden), in diesem Verzeichnis geschrieben.
In addition, if the variable is set to `af_unix:[<socket_type>:]<absolute-pathname>`, Git will try to open the path as a Unix Domain Socket. The socket type can be either `stream` or `dgram`.
Zurücksetzen der Variable oder setzen auf einen leeren Wert, "0" oder "false" (unabhängig von Groß-/Kleinschreibung) deaktiviert Ablaufverfolgungsmeldungen.
See [Trace2 documentation](https://git-scm.com/docs/api-trace2/de) for full details.

[](https://git-scm.com/docs/git/de#git-codeGITTRACE2EVENTcode)`GIT_TRACE2_EVENT`

This setting writes a JSON-based format that is suited for machine interpretation. See `GIT_TRACE2` for available trace output options and [Trace2 documentation](https://git-scm.com/docs/api-trace2/de) for full details.

[](https://git-scm.com/docs/git/de#git-codeGITTRACE2PERFcode)`GIT_TRACE2_PERF`

In addition to the text-based messages available in `GIT_TRACE2`, this setting writes a column-based format for understanding nesting regions. See `GIT_TRACE2` for available trace output options and [Trace2 documentation](https://git-scm.com/docs/api-trace2/de) for full details.

[](https://git-scm.com/docs/git/de#git-codeGITTRACEREDACTcode)`GIT_TRACE_REDACT`

By default, when tracing is activated, Git redacts the values of cookies, the "Authorization:" header, the "Proxy-Authorization:" header and packfile URIs. Set this variable to `0` to prevent this redaction.

[](https://git-scm.com/docs/git/de#git-codeGITLITERALPATHSPECScode)`GIT_LITERAL_PATHSPECS`

Das Setzen dieser Variable auf 1 veranlasst Git alle Pfadspezifikationen buchstäblich und nicht als Glob-Muster zu interpreieren. Zum Beispiel sucht `GIT_LITERAL_PATHSPECS=1 git log -- '*.c'` nach Commits, die den Pfad `*.c` verrändern, nicht nach Dateien, die das Muster `*.c` betrifft. Das kann gewollt sein, wenn tatsächliche Pfade an Git übergeben werden (z.B. Pfade die von `git ls-tree` ausgegeben wurden oder aus Diffausgaben mit `--raw` o.ä. stammen).

[](https://git-scm.com/docs/git/de#git-codeGITGLOBPATHSPECScode)`GIT_GLOB_PATHSPECS`

Das Setzen dieser Variable auf 1 veranlasst Git alle Pfadspezifikationen als Glob-Muster zu behandeln (Pfadspezifikationsangabe "glob").

[](https://git-scm.com/docs/git/de#git-codeGITNOGLOBPATHSPECScode)`GIT_NOGLOB_PATHSPECS`

Das Setzen dieser Variable auf 1 veranlasst Git alle Pfadspezifikationen buchstäblich zu interpreieren (Pfadspezifikationsangabe "literal").

[](https://git-scm.com/docs/git/de#git-codeGITICASEPATHSPECScode)`GIT_ICASE_PATHSPECS`

Das Setzen dieser Variable auf 1 veranlasst Git bei allen Pfadspezifikationen Groß- und Kleinschreibung zu ignorieren.

[](https://git-scm.com/docs/git/de#git-codeGITREFLOGACTIONcode)`GIT_REFLOG_ACTION`

Wenn eine Referenz aktualisiert wird, werden Reflog-Einträge erstellt, um den Grund, dass die Referenz aktualisiert wurde (üblicherweise ist das die Bezeichnung des hochrangigen Befehls, der die Referenz aktualisiert hat), sowie den alten und neuen Wert der Referenz nachvollziehen zu können. Geskriptete Porcelain-Befehle können die Hilfsfunktion set_reflog_action in `git-sh-setup` um ihren Namen in diese Variable einzutragen, wenn sie vom Endbenutzer als Befehl der obersten Ebene aufgerufen werden, damit dieser im Reflog festgehalten wird.

[](https://git-scm.com/docs/git/de#git-codeGITREFPARANOIAcode)`GIT_REF_PARANOIA`

If set to `0`, ignore broken or badly named refs when iterating over lists of refs. Normally Git will try to include any such refs, which may cause some operations to fail. This is usually preferable, as potentially destructive operations (e.g., [git-prune[1]](https://git-scm.com/docs/git-prune/de)) are better off aborting rather than ignoring broken refs (and thus considering the history they point to as not worth saving). The default value is `1` (i.e., be paranoid about detecting and aborting all operations). You should not normally need to set this to `0`, but it may be useful when trying to salvage data from a corrupted repository.

[](https://git-scm.com/docs/git/de#git-codeGITALLOWPROTOCOLcode)`GIT_ALLOW_PROTOCOL`

If set to a colon-separated list of protocols, behave as if `protocol.allow` is set to `never`, and each of the listed protocols has `protocol.<name>.allow` set to `always` (overriding any existing configuration). See the description of `protocol.allow` in [git-config[1]](https://git-scm.com/docs/git-config/de) for more details.

[](https://git-scm.com/docs/git/de#git-codeGITPROTOCOLFROMUSERcode)`GIT_PROTOCOL_FROM_USER`

Set to 0 to prevent protocols used by fetch/push/clone which are configured to the `user` state. This is useful to restrict recursive submodule initialization from an untrusted repository or for programs which feed potentially-untrusted URLS to git commands. See [git-config[1]](https://git-scm.com/docs/git-config/de) for more details.

[](https://git-scm.com/docs/git/de#git-codeGITPROTOCOLcode)`GIT_PROTOCOL`

Nur zum internen Gebrauch. Wird beim Handshake des Git Wire Protokolls verwendet. Enthält eine durch Doppelpunkte _:_ getrennte Liste von Schlüsseln mit optionalen Werten _schlüssel[=wert]_. Unbekannte Schlüssel und Werte müssen ignoriert werden.
Note that servers may need to be configured to allow this variable to pass over some transports. It will be propagated automatically when accessing local repositories (i.e., `file://` or a filesystem path), as well as over the `git://` protocol. For git-over-http, it should work automatically in most configurations, but see the discussion in [git-http-backend[1]](https://git-scm.com/docs/git-http-backend/de). For git-over-ssh, the ssh server may need to be configured to allow clients to pass this variable (e.g., by using `AcceptEnv GIT_PROTOCOL` with OpenSSH).
This configuration is optional. If the variable is not propagated, then clients will fall back to the original "v0" protocol (but may miss out on some performance improvements or features). This variable currently only affects clones and fetches; it is not yet used for pushes (but may be in the future).

[](https://git-scm.com/docs/git/de#git-codeGITOPTIONALLOCKScode)`GIT_OPTIONAL_LOCKS`

If set to `0`, Git will complete any requested operation without performing any optional sub-operations that require taking a lock. For example, this will prevent `git status` from refreshing the index as a side effect. This is useful for processes running in the background which do not want to cause lock contention with other operations on the repository. Defaults to `1`.

[](https://git-scm.com/docs/git/de#git-codeGITREDIRECTSTDINcode)`GIT_REDIRECT_STDIN`


[](https://git-scm.com/docs/git/de#git-codeGITREDIRECTSTDOUTcode)`GIT_REDIRECT_STDOUT`


[](https://git-scm.com/docs/git/de#git-codeGITREDIRECTSTDERRcode)`GIT_REDIRECT_STDERR`

Nur unter Windows: Erlaubt es die Standardeingabe/-ausgabe/-fehlerausgabe auf die in diesen Umgebungsvariablen angegebenen Pfade umzuleiten. Dies ist besonders hilfreich bei Multithreading-Anwendungen bei denen die Standardmethode diese Datenströme mit `CreateProcess()` keine Option ist, da das bewirken würde, dass alle weiteren Prozesse diese erben, was reguläre Git-Operationen blockieren kann. Der Hauptanwendungsfall ist die Verwendung von benannten Pipes (z.B. `\\.\pipe\my-git-stdin-123`).
Es werden zwei besondere Werte unterstützt: `off` deaktiviert den entsprechenden Standarddatenstrom und wenn `GIT_REDIRECT_STDERR` auf `2>&1` gesetzt ist wird die Standardfehlerausgabe in den selben Strom wie die Standardausgabe geleitet.

[](https://git-scm.com/docs/git/de#git-codeGITPRINTSHA1ELLIPSIScodeveraltet)`GIT_PRINT_SHA1_ELLIPSIS` (veraltet)

If set to `yes`, print an ellipsis following an (abbreviated) SHA-1 value. This affects indications of detached HEADs ([git-checkout[1]](https://git-scm.com/docs/git-checkout/de)) and the raw diff output ([git-diff[1]](https://git-scm.com/docs/git-diff/de)). Printing an ellipsis in the cases mentioned is no longer considered adequate and support for it is likely to be removed in the foreseeable future (along with the variable).
##  [](https://git-scm.com/docs/git/de#_diskussion)Diskussion
Mehr Details zum den folgenden Themen sind im [Kapitel "Git concepts" des Benutzerhandbuchs](https://git-scm.com/docs/user-manual/de#git-concepts) und unter [gitcore-tutorial[7]](https://git-scm.com/docs/gitcore-tutorial/de) verfügbar.
Ein Git-Projekt besteht normalerweise aus einem Arbeitsverzeichnis mit einem „.git“-Unterverzeichnis auf der obersten Ebene. Das „.git“-Verzeichnis enthält unter anderem eine komprimierte Objektdatenbank, die den vollständigen Projektverlauf wiedergibt, eine „Index“-Datei, die diesen Verlauf mit dem aktuellen Inhalt des Arbeitsbereichs verknüpft und Pointer in diesem Verlauf benennt, wie z.B. Tags und Branch-Heads.
Die Objektdatenbank enthält drei Hauptarten von Objekten: Blobs, die Dateiinformationen enthalten; Trees, die auf Blobs und andere Trees verweisen, um Verzeichnisstrukturen abzubilden; und Commits, die jeweils auf einen einzelnen Tree und eine gewisse Anzahl Eltern-Commits verweisen.
Der Commit, in anderen Systemen auch „Changeset“ oder „Version“ genannt, stellt einen Schritt in der Projekthistorie dar und jeder Eltern-Commit stellt einen direkt vorhergehenden Schritt dar. Commits mit mehr als einem Eltern-Commit stellen Zusammenführungen verschiedener Entwicklungslinien dar.
Alle Objekte werden mit dem SHA1-Hash ihres Inhalts bezeichnet. Dieser wird normalerweise als 40-stellige Hexadezimalzahl angegeben. Diese Bezeichnungen sind eindeutig. Ein einzelner signierter Commit kann die gesamte Historie bis zu diesem Commit verifizieren. Zu diesem Zweck wird eine vierte Objektart, die Markierung angeboten.
Beim Erstellen werden Objekte in individuellen Dateien gespeichert, können aber aus Effizienzgründen später zusammen in sogenannten Packdateien komprimiert werden.
Benannte Zeiger, die Referenzen genannt werden, markieren interessante Punkte in der Historie. Eine Referenz kann auf ein Objekt oder eine andere Referenz verweisen. Referenzen deren Bezeichnung mit `ref/head/` beginnt enthalten die SHA1-Bezeichnung de letzten Commits (der „Spitze“) eines Entwicklungszweigs. SHA1-Bezeichnungen interessanter Markierungen werden unter `ref/tags/` gespeichert. Eine besondere Referenz namens `HEAD` verweist auf die Bezeichnung des momnentan ausgecheckten Entwicklungszweigs.
Die Indexdatei wird mit einer Liste aller Pfade, sowie pro Pfad einem Blob-Objekt und einer Reihe von Attributen initialisiert. Das Blob-Objekt repräsentiert die Inhalte der Datei gemäß der Spitze des aktuellen Entwicklungszweigs. Die Attribute (zuletzt geändert, Größe, etc.) werden von der entsprechenden Datei im Arbeitsverzeichnis genommen. Spätere Änderungen am Arbeitsverzeichnis können durch Vergleichen dieser Attribute ermittelt werden. Der Index kann mit neuen Inhalten aktualisiert werden und aus dem Inhalt des Indexes können neue Commits erstellt werden.
Der Index kann auch mehrere Einträge (genannt „Stages“) eines bestimmten Pfads enthalten. Diese Stages enthalten verschiedene noch nicht zusammengeführte Versionen einer Datei während eines Merges.
##  [](https://git-scm.com/docs/git/de#_weitere_dokumentation)WEITERE DOKUMENTATION
Siehe die Verweise im Abschnitt „Beschreibung“ um mit der Verwendung von Git zu beginnen. Nachfolgend finden Sie vermutlich mehr Details als es für einen erstmaligen Benutzer nötig ist.
Das [Kapitel „Git concepts“ des Benutzerhandbuchs](https://git-scm.com/docs/user-manual/de#git-concepts) und [gitcore-tutorial[7]](https://git-scm.com/docs/gitcore-tutorial/de) stellen eine Einführung in die zugrundeliegende Git-Architektur zur Verfügung.
Siehe [gitworkflows[7]](https://git-scm.com/docs/gitworkflows/de) für eine Übersicht über empfohlene Arbeitsabläufe.
In den [Howto](https://git-scm.com/docs/howto-index/de)-Dokumenten finden Sie nützliche Beispiele.
Die Interna sind in der [Git-API-Dokumentation](https://git-scm.com/docs/api-index/de) dokumentiert.
Für Benutzer, die von CVS migrieren könnte auch [gitcvs-migration[7]](https://git-scm.com/docs/gitcvs-migration/de) interessant sein.
##  [](https://git-scm.com/docs/git/de#_autoren)Autoren
Git wurde ursprünglich von Linus Torvalds geschrieben und wird jetzt von Junio C Hamano weitergeführt. Zahlreiche Beiträge sind über die Git-E-Mail-Verteilerliste <git@vger.kernel.org> entstanden. Unter <http://www.openhub.net/p/git/contributors/summary> steht eine etwas vollständigere Liste der Mitwirkenden bereit.
Wenn sie einen Klon von git.git haben, können Sie sich mit [git-shortlog[1]](https://git-scm.com/docs/git-shortlog/de) und [git-blame[1]](https://git-scm.com/docs/git-blame/de) die Urheber einzelner Projektteile anzeigen lassen.
##  [](https://git-scm.com/docs/git/de#_fehler_melden)Fehler melden
Report bugs to the Git mailing list <git@vger.kernel.org> where the development and maintenance is primarily done. You do not have to be subscribed to the list to send a message there. See the list archive at <https://lore.kernel.org/git> for previous bug reports and other discussions.
Sicherheitsrelevante Fehler sollten vetraulich an die Git-Sicherheits-E-Mail-Verteilerliste <git-security@googlegroups.com> gemeldet werden.
##  [](https://git-scm.com/docs/git/de#_siehe_auch)SIEHE AUCH
[gittutorial[7]](https://git-scm.com/docs/gittutorial/de), [gittutorial-2[7]](https://git-scm.com/docs/gittutorial-2/de), [giteveryday[7]](https://git-scm.com/docs/giteveryday/de), [gitcvs-migration[7]](https://git-scm.com/docs/gitcvs-migration/de), [gitglossary[7]](https://git-scm.com/docs/gitglossary/de), [gitcore-tutorial[7]](https://git-scm.com/docs/gitcore-tutorial/de), [gitcli[7]](https://git-scm.com/docs/gitcli/de), [Das Git-Benutzerhandbuch](https://git-scm.com/docs/user-manual/de), [gitworkflows[7]](https://git-scm.com/docs/gitworkflows/de)
##  [](https://git-scm.com/docs/git/de#_git)GIT
Teil der [git[1]](https://git-scm.com/docs/git/de) Suite
### git
[About this site](https://git-scm.com/site)
Patches, suggestions, and comments are welcome.
Git is a member of [Software Freedom Conservancy](https://git-scm.com/sfc)
